@@ -317,19 +317,17 @@ static const QDataStream::Status qtscript_QDataStream_Status_values[] = {
     QDataStream::Ok
     , QDataStream::ReadPastEnd
     , QDataStream::ReadCorruptData
-    , QDataStream::WriteFailed
 };
 
 static const char * const qtscript_QDataStream_Status_keys[] = {
     "Ok"
     , "ReadPastEnd"
     , "ReadCorruptData"
-    , "WriteFailed"
 };
 
 static QString qtscript_QDataStream_Status_toStringHelper(QDataStream::Status value)
 {
-    if ((value >= QDataStream::Ok) && (value <= QDataStream::WriteFailed))
+    if ((value >= QDataStream::Ok) && (value <= QDataStream::ReadCorruptData))
         return qtscript_QDataStream_Status_keys[static_cast<int>(value)-static_cast<int>(QDataStream::Ok)];
     return QString();
 }
@@ -348,7 +346,7 @@ static void qtscript_QDataStream_Status_fromScriptValue(const QScriptValue &valu
 static QScriptValue qtscript_construct_QDataStream_Status(QScriptContext *context, QScriptEngine *engine)
 {
     int arg = context->argument(0).toInt32();
-    if ((arg >= QDataStream::Ok) && (arg <= QDataStream::WriteFailed))
+    if ((arg >= QDataStream::Ok) && (arg <= QDataStream::ReadCorruptData))
         return qScriptValueFromValue(engine,  static_cast<QDataStream::Status>(arg));
     return context->throwError(QString::fromLatin1("Status(): invalid enum value (%0)").arg(arg));
 }
@@ -372,7 +370,7 @@ static QScriptValue qtscript_create_QDataStream_Status_class(QScriptEngine *engi
         qtscript_QDataStream_Status_valueOf, qtscript_QDataStream_Status_toString);
     qScriptRegisterMetaType<QDataStream::Status>(engine, qtscript_QDataStream_Status_toScriptValue,
         qtscript_QDataStream_Status_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 4; ++i) {
+    for (int i = 0; i < 3; ++i) {
         clazz.setProperty(QString::fromLatin1(qtscript_QDataStream_Status_keys[i]),
             engine->newVariant(qVariantFromValue(qtscript_QDataStream_Status_values[i])),
             QScriptValue::ReadOnly | QScriptValue::Undeletable);
