@@ -4,7 +4,6 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
-#include <__package_shared.h>
 
 #include <qsettings.h>
 #include <QStringList>
@@ -143,11 +142,11 @@ static QScriptValue qtscript_QSettings_throw_ambiguity_error_helper(
 
 Q_DECLARE_METATYPE(QSettings*)
 Q_DECLARE_METATYPE(QtScriptShell_QSettings*)
-Q_DECLARE_METATYPE(QSettings::Scope)
 Q_DECLARE_METATYPE(QSettings::Format)
 Q_DECLARE_METATYPE(QSettings::Status)
+Q_DECLARE_METATYPE(QSettings::Scope)
 Q_DECLARE_METATYPE(QTextCodec*)
-Q_DECLARE_METATYPE(const char*)
+Q_DECLARE_METATYPE(char*)
 
 static QScriptValue qtscript_create_enum_class_helper(
     QScriptEngine *engine,
@@ -163,73 +162,6 @@ static QScriptValue qtscript_create_enum_class_helper(
     return engine->newFunction(construct, proto, 1);
 }
 
-//
-// QSettings::Scope
-//
-
-static const QSettings::Scope qtscript_QSettings_Scope_values[] = {
-    QSettings::UserScope
-    , QSettings::SystemScope
-};
-
-static const char * const qtscript_QSettings_Scope_keys[] = {
-    "UserScope"
-    , "SystemScope"
-};
-
-static QString qtscript_QSettings_Scope_toStringHelper(QSettings::Scope value)
-{
-    if ((value >= QSettings::UserScope) && (value <= QSettings::SystemScope))
-        return qtscript_QSettings_Scope_keys[static_cast<int>(value)-static_cast<int>(QSettings::UserScope)];
-    return QString();
-}
-
-static QScriptValue qtscript_QSettings_Scope_toScriptValue(QScriptEngine *engine, const QSettings::Scope &value)
-{
-    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QSettings"));
-    return clazz.property(qtscript_QSettings_Scope_toStringHelper(value));
-}
-
-static void qtscript_QSettings_Scope_fromScriptValue(const QScriptValue &value, QSettings::Scope &out)
-{
-    out = qvariant_cast<QSettings::Scope>(value.toVariant());
-}
-
-static QScriptValue qtscript_construct_QSettings_Scope(QScriptContext *context, QScriptEngine *engine)
-{
-    int arg = context->argument(0).toInt32();
-    if ((arg >= QSettings::UserScope) && (arg <= QSettings::SystemScope))
-        return qScriptValueFromValue(engine,  static_cast<QSettings::Scope>(arg));
-    return context->throwError(QString::fromLatin1("Scope(): invalid enum value (%0)").arg(arg));
-}
-
-static QScriptValue qtscript_QSettings_Scope_valueOf(QScriptContext *context, QScriptEngine *engine)
-{
-    QSettings::Scope value = qscriptvalue_cast<QSettings::Scope>(context->thisObject());
-    return QScriptValue(engine, static_cast<int>(value));
-}
-
-static QScriptValue qtscript_QSettings_Scope_toString(QScriptContext *context, QScriptEngine *engine)
-{
-    QSettings::Scope value = qscriptvalue_cast<QSettings::Scope>(context->thisObject());
-    return QScriptValue(engine, qtscript_QSettings_Scope_toStringHelper(value));
-}
-
-static QScriptValue qtscript_create_QSettings_Scope_class(QScriptEngine *engine, QScriptValue &clazz)
-{
-    QScriptValue ctor = qtscript_create_enum_class_helper(
-        engine, qtscript_construct_QSettings_Scope,
-        qtscript_QSettings_Scope_valueOf, qtscript_QSettings_Scope_toString);
-    qScriptRegisterMetaType<QSettings::Scope>(engine, qtscript_QSettings_Scope_toScriptValue,
-        qtscript_QSettings_Scope_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 2; ++i) {
-        clazz.setProperty(QString::fromLatin1(qtscript_QSettings_Scope_keys[i]),
-            engine->newVariant(qVariantFromValue(qtscript_QSettings_Scope_values[i])),
-            QScriptValue::ReadOnly | QScriptValue::Undeletable);
-    }
-    return ctor;
-}
-
 //
 // QSettings::Format
 //
@@ -404,6 +336,73 @@ static QScriptValue qtscript_create_QSettings_Status_class(QScriptEngine *engine
     return ctor;
 }
 
+//
+// QSettings::Scope
+//
+
+static const QSettings::Scope qtscript_QSettings_Scope_values[] = {
+    QSettings::UserScope
+    , QSettings::SystemScope
+};
+
+static const char * const qtscript_QSettings_Scope_keys[] = {
+    "UserScope"
+    , "SystemScope"
+};
+
+static QString qtscript_QSettings_Scope_toStringHelper(QSettings::Scope value)
+{
+    if ((value >= QSettings::UserScope) && (value <= QSettings::SystemScope))
+        return qtscript_QSettings_Scope_keys[static_cast<int>(value)-static_cast<int>(QSettings::UserScope)];
+    return QString();
+}
+
+static QScriptValue qtscript_QSettings_Scope_toScriptValue(QScriptEngine *engine, const QSettings::Scope &value)
+{
+    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QSettings"));
+    return clazz.property(qtscript_QSettings_Scope_toStringHelper(value));
+}
+
+static void qtscript_QSettings_Scope_fromScriptValue(const QScriptValue &value, QSettings::Scope &out)
+{
+    out = qvariant_cast<QSettings::Scope>(value.toVariant());
+}
+
+static QScriptValue qtscript_construct_QSettings_Scope(QScriptContext *context, QScriptEngine *engine)
+{
+    int arg = context->argument(0).toInt32();
+    if ((arg >= QSettings::UserScope) && (arg <= QSettings::SystemScope))
+        return qScriptValueFromValue(engine,  static_cast<QSettings::Scope>(arg));
+    return context->throwError(QString::fromLatin1("Scope(): invalid enum value (%0)").arg(arg));
+}
+
+static QScriptValue qtscript_QSettings_Scope_valueOf(QScriptContext *context, QScriptEngine *engine)
+{
+    QSettings::Scope value = qscriptvalue_cast<QSettings::Scope>(context->thisObject());
+    return QScriptValue(engine, static_cast<int>(value));
+}
+
+static QScriptValue qtscript_QSettings_Scope_toString(QScriptContext *context, QScriptEngine *engine)
+{
+    QSettings::Scope value = qscriptvalue_cast<QSettings::Scope>(context->thisObject());
+    return QScriptValue(engine, qtscript_QSettings_Scope_toStringHelper(value));
+}
+
+static QScriptValue qtscript_create_QSettings_Scope_class(QScriptEngine *engine, QScriptValue &clazz)
+{
+    QScriptValue ctor = qtscript_create_enum_class_helper(
+        engine, qtscript_construct_QSettings_Scope,
+        qtscript_QSettings_Scope_valueOf, qtscript_QSettings_Scope_toString);
+    qScriptRegisterMetaType<QSettings::Scope>(engine, qtscript_QSettings_Scope_toScriptValue,
+        qtscript_QSettings_Scope_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
+    for (int i = 0; i < 2; ++i) {
+        clazz.setProperty(QString::fromLatin1(qtscript_QSettings_Scope_keys[i]),
+            engine->newVariant(qVariantFromValue(qtscript_QSettings_Scope_values[i])),
+            QScriptValue::ReadOnly | QScriptValue::Undeletable);
+    }
+    return ctor;
+}
+
 //
 // QSettings
 //
@@ -603,8 +602,8 @@ static QScriptValue qtscript_QSettings_prototype_call(QScriptContext *context, Q
             QTextCodec* _q_arg0 = qscriptvalue_cast<QTextCodec*>(context->argument(0));
             _q_self->setIniCodec(_q_arg0);
             return context->engine()->undefinedValue();
-        } else if (qscriptvalue_cast<const char*>(context->argument(0))) {
-            const char* _q_arg0 = qscriptvalue_cast<const char*>(context->argument(0));
+        } else if (qscriptvalue_cast<char*>(context->argument(0))) {
+            char* _q_arg0 = qscriptvalue_cast<char*>(context->argument(0));
             _q_self->setIniCodec(_q_arg0);
             return context->engine()->undefinedValue();
         }
@@ -865,11 +864,11 @@ QScriptValue qtscript_create_QSettings_class(QScriptEngine *engine)
             fun, QScriptValue::SkipInEnumeration);
     }
 
-    ctor.setProperty(QString::fromLatin1("Scope"),
-        qtscript_create_QSettings_Scope_class(engine, ctor));
     ctor.setProperty(QString::fromLatin1("Format"),
         qtscript_create_QSettings_Format_class(engine, ctor));
     ctor.setProperty(QString::fromLatin1("Status"),
         qtscript_create_QSettings_Status_class(engine, ctor));
+    ctor.setProperty(QString::fromLatin1("Scope"),
+        qtscript_create_QSettings_Scope_class(engine, ctor));
     return ctor;
 }
