@@ -548,19 +548,17 @@ static const QTextStream::Status qtscript_QTextStream_Status_values[] = {
     QTextStream::Ok
     , QTextStream::ReadPastEnd
     , QTextStream::ReadCorruptData
-    , QTextStream::WriteFailed
 };
 
 static const char * const qtscript_QTextStream_Status_keys[] = {
     "Ok"
     , "ReadPastEnd"
     , "ReadCorruptData"
-    , "WriteFailed"
 };
 
 static QString qtscript_QTextStream_Status_toStringHelper(QTextStream::Status value)
 {
-    if ((value >= QTextStream::Ok) && (value <= QTextStream::WriteFailed))
+    if ((value >= QTextStream::Ok) && (value <= QTextStream::ReadCorruptData))
         return qtscript_QTextStream_Status_keys[static_cast<int>(value)-static_cast<int>(QTextStream::Ok)];
     return QString();
 }
@@ -579,7 +577,7 @@ static void qtscript_QTextStream_Status_fromScriptValue(const QScriptValue &valu
 static QScriptValue qtscript_construct_QTextStream_Status(QScriptContext *context, QScriptEngine *engine)
 {
     int arg = context->argument(0).toInt32();
-    if ((arg >= QTextStream::Ok) && (arg <= QTextStream::WriteFailed))
+    if ((arg >= QTextStream::Ok) && (arg <= QTextStream::ReadCorruptData))
         return qScriptValueFromValue(engine,  static_cast<QTextStream::Status>(arg));
     return context->throwError(QString::fromLatin1("Status(): invalid enum value (%0)").arg(arg));
 }
@@ -603,7 +601,7 @@ static QScriptValue qtscript_create_QTextStream_Status_class(QScriptEngine *engi
         qtscript_QTextStream_Status_valueOf, qtscript_QTextStream_Status_toString);
     qScriptRegisterMetaType<QTextStream::Status>(engine, qtscript_QTextStream_Status_toScriptValue,
         qtscript_QTextStream_Status_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 4; ++i) {
+    for (int i = 0; i < 3; ++i) {
         clazz.setProperty(QString::fromLatin1(qtscript_QTextStream_Status_keys[i]),
             engine->newVariant(qVariantFromValue(qtscript_QTextStream_Status_values[i])),
             QScriptValue::ReadOnly | QScriptValue::Undeletable);
