@@ -10,7 +10,6 @@
 #include <QStringList>
 #include <QVariant>
 #include <qbytearray.h>
-#include <qcolor.h>
 #include <qdatastream.h>
 #include <qimage.h>
 #include <qiodevice.h>
@@ -80,7 +79,6 @@ static const char * const qtscript_QImage_function_names[] = {
     , "setPixel"
     , "setText"
     , "size"
-    , "swap"
     , "text"
     , "textKeys"
     , "transformed"
@@ -112,7 +110,7 @@ static const char * const qtscript_QImage_function_signatures[] = {
     , "unsigned int color, MaskMode mode"
     , ""
     , ""
-    , "GlobalColor color\nQColor color\nuint pixel"
+    , "uint pixel"
     , ""
     , ""
     , "InvertMode arg__1"
@@ -143,7 +141,6 @@ static const char * const qtscript_QImage_function_signatures[] = {
     , "QPoint pt, uint index_or_rgb\nint x, int y, uint index_or_rgb"
     , "String key, String value"
     , ""
-    , "QImage other"
     , "String key"
     , ""
     , "QMatrix matrix, TransformationMode mode\nQTransform matrix, TransformationMode mode"
@@ -207,7 +204,6 @@ static const int qtscript_QImage_function_lengths[] = {
     , 2
     , 0
     , 1
-    , 1
     , 0
     , 2
     , 2
@@ -235,7 +231,6 @@ Q_DECLARE_METATYPE(QVector<uint>)
 Q_DECLARE_METATYPE(uchar*)
 Q_DECLARE_METATYPE(QFlags<Qt::ImageConversionFlag>)
 Q_DECLARE_METATYPE(Qt::MaskMode)
-Q_DECLARE_METATYPE(Qt::GlobalColor)
 Q_DECLARE_METATYPE(QIODevice*)
 Q_DECLARE_METATYPE(QDataStream*)
 Q_DECLARE_METATYPE(Qt::AspectRatioMode)
@@ -434,7 +429,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 54;
+        _id = 0xBABE0000 + 53;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -624,19 +619,9 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
 
     case 17:
     if (context->argumentCount() == 1) {
-        if ((qMetaTypeId<Qt::GlobalColor>() == context->argument(0).toVariant().userType())) {
-            Qt::GlobalColor _q_arg0 = qscriptvalue_cast<Qt::GlobalColor>(context->argument(0));
-            _q_self->fill(_q_arg0);
-            return context->engine()->undefinedValue();
-        } else if ((qMetaTypeId<QColor>() == context->argument(0).toVariant().userType())) {
-            QColor _q_arg0 = qscriptvalue_cast<QColor>(context->argument(0));
-            _q_self->fill(_q_arg0);
-            return context->engine()->undefinedValue();
-        } else if (context->argument(0).isNumber()) {
-            uint _q_arg0 = context->argument(0).toUInt32();
-            _q_self->fill(_q_arg0);
-            return context->engine()->undefinedValue();
-        }
+        uint _q_arg0 = context->argument(0).toUInt32();
+        _q_self->fill(_q_arg0);
+        return context->engine()->undefinedValue();
     }
     break;
 
@@ -1041,14 +1026,6 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     break;
 
     case 48:
-    if (context->argumentCount() == 1) {
-        QImage _q_arg0 = qscriptvalue_cast<QImage>(context->argument(0));
-        _q_self->swap(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 49:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->text();
         return QScriptValue(context->engine(), _q_result);
@@ -1060,14 +1037,14 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 50:
+    case 49:
     if (context->argumentCount() == 0) {
         QStringList _q_result = _q_self->textKeys();
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
-    case 51:
+    case 50:
     if (context->argumentCount() == 1) {
         if ((qMetaTypeId<QMatrix>() == context->argument(0).toVariant().userType())) {
             QMatrix _q_arg0 = qscriptvalue_cast<QMatrix>(context->argument(0));
@@ -1096,7 +1073,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 52:
+    case 51:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         bool _q_result = _q_self->valid(_q_arg0);
@@ -1110,7 +1087,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 53:
+    case 52:
     if (context->argumentCount() == 1) {
         QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
         operator<<(*_q_arg0, *_q_self);
@@ -1118,7 +1095,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 54: {
+    case 53: {
     QString result = QString::fromLatin1("QImage");
     return QScriptValue(context->engine(), result);
     }
@@ -1241,7 +1218,7 @@ QScriptValue qtscript_create_QImage_class(QScriptEngine *engine)
     engine->setDefaultPrototype(qMetaTypeId<QImage*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QImage*)0));
     proto.setPrototype(engine->defaultPrototype(qMetaTypeId<QPaintDevice*>()));
-    for (int i = 0; i < 55; ++i) {
+    for (int i = 0; i < 54; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QImage_prototype_call, qtscript_QImage_function_lengths[i+3]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QImage_function_names[i+3]),
