@@ -69,7 +69,6 @@ static const char * const qtscript_QPainterPath_function_names[] = {
     , "slopeAtPercent"
     , "subtracted"
     , "subtractedInverted"
-    , "swap"
     , "toFillPolygon"
     , "toFillPolygons"
     , "toReversed"
@@ -131,7 +130,6 @@ static const char * const qtscript_QPainterPath_function_signatures[] = {
     , "qreal t"
     , "QPainterPath r"
     , "QPainterPath r"
-    , "QPainterPath other"
     , "QMatrix matrix\nQTransform matrix"
     , "QMatrix matrix\nQTransform matrix"
     , ""
@@ -195,7 +193,6 @@ static const int qtscript_QPainterPath_function_lengths[] = {
     , 1
     , 1
     , 1
-    , 1
     , 0
     , 1
     , 2
@@ -325,7 +322,7 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 55;
+        _id = 0xBABE0000 + 54;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -861,14 +858,6 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     break;
 
     case 46:
-    if (context->argumentCount() == 1) {
-        QPainterPath _q_arg0 = qscriptvalue_cast<QPainterPath>(context->argument(0));
-        _q_self->swap(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 47:
     if (context->argumentCount() == 0) {
         QPolygonF _q_result = _q_self->toFillPolygon();
         return qScriptValueFromValue(context->engine(), _q_result);
@@ -886,7 +875,7 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     }
     break;
 
-    case 48:
+    case 47:
     if (context->argumentCount() == 0) {
         QList<QPolygonF> _q_result = _q_self->toFillPolygons();
         return qScriptValueFromSequence(context->engine(), _q_result);
@@ -904,14 +893,14 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     }
     break;
 
-    case 49:
+    case 48:
     if (context->argumentCount() == 0) {
         QPainterPath _q_result = _q_self->toReversed();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 50:
+    case 49:
     if (context->argumentCount() == 0) {
         QList<QPolygonF> _q_result = _q_self->toSubpathPolygons();
         return qScriptValueFromSequence(context->engine(), _q_result);
@@ -929,7 +918,7 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     }
     break;
 
-    case 51:
+    case 50:
     if (context->argumentCount() == 1) {
         QPointF _q_arg0 = qscriptvalue_cast<QPointF>(context->argument(0));
         _q_self->translate(_q_arg0);
@@ -943,7 +932,7 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     }
     break;
 
-    case 52:
+    case 51:
     if (context->argumentCount() == 1) {
         QPointF _q_arg0 = qscriptvalue_cast<QPointF>(context->argument(0));
         QPainterPath _q_result = _q_self->translated(_q_arg0);
@@ -957,7 +946,7 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     }
     break;
 
-    case 53:
+    case 52:
     if (context->argumentCount() == 1) {
         QPainterPath _q_arg0 = qscriptvalue_cast<QPainterPath>(context->argument(0));
         QPainterPath _q_result = _q_self->united(_q_arg0);
@@ -965,7 +954,7 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     }
     break;
 
-    case 54:
+    case 53:
     if (context->argumentCount() == 1) {
         QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
         operator<<(*_q_arg0, *_q_self);
@@ -973,7 +962,7 @@ static QScriptValue qtscript_QPainterPath_prototype_call(QScriptContext *context
     }
     break;
 
-    case 55: {
+    case 54: {
     QString result;
     QDebug d(&result);
     d << *_q_self;
@@ -1029,7 +1018,7 @@ QScriptValue qtscript_create_QPainterPath_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QPainterPath*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QPainterPath*)0));
-    for (int i = 0; i < 56; ++i) {
+    for (int i = 0; i < 55; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QPainterPath_prototype_call, qtscript_QPainterPath_function_lengths[i+1]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QPainterPath_function_names[i+1]),
