@@ -34,7 +34,6 @@ static const char * const qtscript_QRegion_function_names[] = {
     , "rects"
     , "setRects"
     , "subtracted"
-    , "swap"
     , "translate"
     , "translated"
     , "unite"
@@ -63,7 +62,6 @@ static const char * const qtscript_QRegion_function_signatures[] = {
     , ""
     , "QRect rect, int num"
     , "QRegion r"
-    , "QRegion other"
     , "QPoint p\nint dx, int dy"
     , "QPoint p\nint dx, int dy"
     , "QRect r"
@@ -92,7 +90,6 @@ static const int qtscript_QRegion_function_lengths[] = {
     , 0
     , 2
     , 1
-    , 1
     , 2
     , 2
     , 1
@@ -215,7 +212,7 @@ static QScriptValue qtscript_QRegion_prototype_call(QScriptContext *context, QSc
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 22;
+        _id = 0xBABE0000 + 21;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -362,14 +359,6 @@ static QScriptValue qtscript_QRegion_prototype_call(QScriptContext *context, QSc
     break;
 
     case 15:
-    if (context->argumentCount() == 1) {
-        QRegion _q_arg0 = qscriptvalue_cast<QRegion>(context->argument(0));
-        _q_self->swap(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 16:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         _q_self->translate(_q_arg0);
@@ -383,7 +372,7 @@ static QScriptValue qtscript_QRegion_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 17:
+    case 16:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         QRegion _q_result = _q_self->translated(_q_arg0);
@@ -397,7 +386,7 @@ static QScriptValue qtscript_QRegion_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 18:
+    case 17:
     if (context->argumentCount() == 1) {
         QRect _q_arg0 = qscriptvalue_cast<QRect>(context->argument(0));
         QRegion _q_result = _q_self->unite(_q_arg0);
@@ -405,7 +394,7 @@ static QScriptValue qtscript_QRegion_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 19:
+    case 18:
     if (context->argumentCount() == 1) {
         if ((qMetaTypeId<QRect>() == context->argument(0).toVariant().userType())) {
             QRect _q_arg0 = qscriptvalue_cast<QRect>(context->argument(0));
@@ -419,7 +408,7 @@ static QScriptValue qtscript_QRegion_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 20:
+    case 19:
     if (context->argumentCount() == 1) {
         QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
         operator<<(*_q_arg0, *_q_self);
@@ -427,7 +416,7 @@ static QScriptValue qtscript_QRegion_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 21:
+    case 20:
     if (context->argumentCount() == 1) {
         QRegion _q_arg0 = qscriptvalue_cast<QRegion>(context->argument(0));
         QRegion _q_result = _q_self->xored(_q_arg0);
@@ -435,7 +424,7 @@ static QScriptValue qtscript_QRegion_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 22: {
+    case 21: {
     QString result;
     QDebug d(&result);
     d << *_q_self;
@@ -534,7 +523,7 @@ QScriptValue qtscript_create_QRegion_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QRegion*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QRegion*)0));
-    for (int i = 0; i < 23; ++i) {
+    for (int i = 0; i < 22; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QRegion_prototype_call, qtscript_QRegion_function_lengths[i+1]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QRegion_function_names[i+1]),
