@@ -4,7 +4,6 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
-#include <__package_shared.h>
 
 #include <qcoreapplication.h>
 #include <QStringList>
@@ -33,7 +32,6 @@ static const char * const qtscript_QCoreApplication_function_names[] = {
     , "hasPendingEvents"
     , "installTranslator"
     , "instance"
-    , "isSetuidAllowed"
     , "libraryPaths"
     , "postEvent"
     , "processEvents"
@@ -44,7 +42,6 @@ static const char * const qtscript_QCoreApplication_function_names[] = {
     , "sendPostedEvents"
     , "setAttribute"
     , "setLibraryPaths"
-    , "setSetuidAllowed"
     , "startingUp"
     , "testAttribute"
     , "translate"
@@ -68,20 +65,18 @@ static const char * const qtscript_QCoreApplication_function_signatures[] = {
     , "QTranslator messageFile"
     , ""
     , ""
-    , ""
-    , "QObject receiver, QEvent event, int priority"
+    , "QObject receiver, QEvent event\nQObject receiver, QEvent event, int priority"
     , "ProcessEventsFlags flags\nProcessEventsFlags flags, int maxtime"
     , "String arg__1"
-    , "QObject receiver, int eventType"
+    , "QObject receiver\nQObject receiver, int eventType"
     , "QTranslator messageFile"
     , "QObject receiver, QEvent event"
-    , "QObject receiver, int event_type"
+    , "\nQObject receiver, int event_type"
     , "ApplicationAttribute attribute, bool on"
     , "List arg__1"
-    , "bool allow"
     , ""
     , "ApplicationAttribute attribute"
-    , "char context, char key, char disambiguation, int n"
+    , "char context, char key, char disambiguation, Encoding encoding\nchar context, char key, char disambiguation, Encoding encoding, int n"
     // prototype
     , "QObject arg__1, QEvent arg__2"
 ""
@@ -102,7 +97,6 @@ static const int qtscript_QCoreApplication_function_lengths[] = {
     , 1
     , 0
     , 0
-    , 0
     , 3
     , 2
     , 1
@@ -112,10 +106,9 @@ static const int qtscript_QCoreApplication_function_lengths[] = {
     , 2
     , 2
     , 1
-    , 1
     , 0
     , 1
-    , 4
+    , 5
     // prototype
     , 2
     , 0
@@ -134,13 +127,94 @@ static QScriptValue qtscript_QCoreApplication_throw_ambiguity_error_helper(
 
 Q_DECLARE_METATYPE(QCoreApplication*)
 Q_DECLARE_METATYPE(QtScriptShell_QCoreApplication*)
+Q_DECLARE_METATYPE(QCoreApplication::Encoding)
 Q_DECLARE_METATYPE(QEvent*)
 Q_DECLARE_METATYPE(QTranslator*)
 Q_DECLARE_METATYPE(QFlags<QEventLoop::ProcessEventsFlag>)
 Q_DECLARE_METATYPE(Qt::ApplicationAttribute)
-Q_DECLARE_METATYPE(const char*)
 Q_DECLARE_METATYPE(char**)
 
+static QScriptValue qtscript_create_enum_class_helper(
+    QScriptEngine *engine,
+    QScriptEngine::FunctionSignature construct,
+    QScriptEngine::FunctionSignature valueOf,
+    QScriptEngine::FunctionSignature toString)
+{
+    QScriptValue proto = engine->newObject();
+    proto.setProperty(QString::fromLatin1("valueOf"),
+        engine->newFunction(valueOf), QScriptValue::SkipInEnumeration);
+    proto.setProperty(QString::fromLatin1("toString"),
+        engine->newFunction(toString), QScriptValue::SkipInEnumeration);
+    return engine->newFunction(construct, proto, 1);
+}
+
+//
+// QCoreApplication::Encoding
+//
+
+static const QCoreApplication::Encoding qtscript_QCoreApplication_Encoding_values[] = {
+    QCoreApplication::CodecForTr
+    , QCoreApplication::UnicodeUTF8
+};
+
+static const char * const qtscript_QCoreApplication_Encoding_keys[] = {
+    "CodecForTr"
+    , "UnicodeUTF8"
+};
+
+static QString qtscript_QCoreApplication_Encoding_toStringHelper(QCoreApplication::Encoding value)
+{
+    if ((value >= QCoreApplication::CodecForTr) && (value <= QCoreApplication::UnicodeUTF8))
+        return qtscript_QCoreApplication_Encoding_keys[static_cast<int>(value)-static_cast<int>(QCoreApplication::CodecForTr)];
+    return QString();
+}
+
+static QScriptValue qtscript_QCoreApplication_Encoding_toScriptValue(QScriptEngine *engine, const QCoreApplication::Encoding &value)
+{
+    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QCoreApplication"));
+    return clazz.property(qtscript_QCoreApplication_Encoding_toStringHelper(value));
+}
+
+static void qtscript_QCoreApplication_Encoding_fromScriptValue(const QScriptValue &value, QCoreApplication::Encoding &out)
+{
+    out = qvariant_cast<QCoreApplication::Encoding>(value.toVariant());
+}
+
+static QScriptValue qtscript_construct_QCoreApplication_Encoding(QScriptContext *context, QScriptEngine *engine)
+{
+    int arg = context->argument(0).toInt32();
+    if ((arg >= QCoreApplication::CodecForTr) && (arg <= QCoreApplication::UnicodeUTF8))
+        return qScriptValueFromValue(engine,  static_cast<QCoreApplication::Encoding>(arg));
+    return context->throwError(QString::fromLatin1("Encoding(): invalid enum value (%0)").arg(arg));
+}
+
+static QScriptValue qtscript_QCoreApplication_Encoding_valueOf(QScriptContext *context, QScriptEngine *engine)
+{
+    QCoreApplication::Encoding value = qscriptvalue_cast<QCoreApplication::Encoding>(context->thisObject());
+    return QScriptValue(engine, static_cast<int>(value));
+}
+
+static QScriptValue qtscript_QCoreApplication_Encoding_toString(QScriptContext *context, QScriptEngine *engine)
+{
+    QCoreApplication::Encoding value = qscriptvalue_cast<QCoreApplication::Encoding>(context->thisObject());
+    return QScriptValue(engine, qtscript_QCoreApplication_Encoding_toStringHelper(value));
+}
+
+static QScriptValue qtscript_create_QCoreApplication_Encoding_class(QScriptEngine *engine, QScriptValue &clazz)
+{
+    QScriptValue ctor = qtscript_create_enum_class_helper(
+        engine, qtscript_construct_QCoreApplication_Encoding,
+        qtscript_QCoreApplication_Encoding_valueOf, qtscript_QCoreApplication_Encoding_toString);
+    qScriptRegisterMetaType<QCoreApplication::Encoding>(engine, qtscript_QCoreApplication_Encoding_toScriptValue,
+        qtscript_QCoreApplication_Encoding_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
+    for (int i = 0; i < 2; ++i) {
+        clazz.setProperty(QString::fromLatin1(qtscript_QCoreApplication_Encoding_keys[i]),
+            engine->newVariant(qVariantFromValue(qtscript_QCoreApplication_Encoding_values[i])),
+            QScriptValue::ReadOnly | QScriptValue::Undeletable);
+    }
+    return ctor;
+}
+
 //
 // QCoreApplication
 //
@@ -163,7 +237,7 @@ static QScriptValue qtscript_QCoreApplication_prototype_call(QScriptContext *con
     if (!_q_self) {
         return context->throwError(QScriptContext::TypeError,
             QString::fromLatin1("QCoreApplication.%0(): this object is not a QCoreApplication")
-            .arg(qtscript_QCoreApplication_function_names[_id+27]));
+            .arg(qtscript_QCoreApplication_function_names[_id+25]));
     }
 
     switch (_id) {
@@ -185,8 +259,8 @@ static QScriptValue qtscript_QCoreApplication_prototype_call(QScriptContext *con
     Q_ASSERT(false);
     }
     return qtscript_QCoreApplication_throw_ambiguity_error_helper(context,
-        qtscript_QCoreApplication_function_names[_id+27],
-        qtscript_QCoreApplication_function_signatures[_id+27]);
+        qtscript_QCoreApplication_function_names[_id+25],
+        qtscript_QCoreApplication_function_signatures[_id+25]);
 }
 
 static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *context, QScriptEngine *)
@@ -289,8 +363,8 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     case 10:
     if (context->argumentCount() == 1) {
         QTranslator* _q_arg0 = qscriptvalue_cast<QTranslator*>(context->argument(0));
-        bool _q_result = QCoreApplication::installTranslator(_q_arg0);
-        return QScriptValue(context->engine(), _q_result);
+        QCoreApplication::installTranslator(_q_arg0);
+        return context->engine()->undefinedValue();
     }
     break;
 
@@ -302,20 +376,13 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     break;
 
     case 12:
-    if (context->argumentCount() == 0) {
-        bool _q_result = QCoreApplication::isSetuidAllowed();
-        return QScriptValue(context->engine(), _q_result);
-    }
-    break;
-
-    case 13:
     if (context->argumentCount() == 0) {
         QStringList _q_result = QCoreApplication::libraryPaths();
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
-    case 14:
+    case 13:
     if (context->argumentCount() == 2) {
         QObject* _q_arg0 = context->argument(0).toQObject();
         QEvent* _q_arg1 = qscriptvalue_cast<QEvent*>(context->argument(1));
@@ -331,7 +398,7 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 15:
+    case 14:
     if (context->argumentCount() == 0) {
         QCoreApplication::processEvents();
         return context->engine()->undefinedValue();
@@ -349,7 +416,7 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 16:
+    case 15:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         QCoreApplication::removeLibraryPath(_q_arg0);
@@ -357,7 +424,7 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 17:
+    case 16:
     if (context->argumentCount() == 1) {
         QObject* _q_arg0 = context->argument(0).toQObject();
         QCoreApplication::removePostedEvents(_q_arg0);
@@ -371,15 +438,15 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 18:
+    case 17:
     if (context->argumentCount() == 1) {
         QTranslator* _q_arg0 = qscriptvalue_cast<QTranslator*>(context->argument(0));
-        bool _q_result = QCoreApplication::removeTranslator(_q_arg0);
-        return QScriptValue(context->engine(), _q_result);
+        QCoreApplication::removeTranslator(_q_arg0);
+        return context->engine()->undefinedValue();
     }
     break;
 
-    case 19:
+    case 18:
     if (context->argumentCount() == 2) {
         QObject* _q_arg0 = context->argument(0).toQObject();
         QEvent* _q_arg1 = qscriptvalue_cast<QEvent*>(context->argument(1));
@@ -388,16 +455,11 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 20:
+    case 19:
     if (context->argumentCount() == 0) {
         QCoreApplication::sendPostedEvents();
         return context->engine()->undefinedValue();
     }
-    if (context->argumentCount() == 1) {
-        QObject* _q_arg0 = context->argument(0).toQObject();
-        QCoreApplication::sendPostedEvents(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
     if (context->argumentCount() == 2) {
         QObject* _q_arg0 = context->argument(0).toQObject();
         int _q_arg1 = context->argument(1).toInt32();
@@ -406,7 +468,7 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 21:
+    case 20:
     if (context->argumentCount() == 1) {
         Qt::ApplicationAttribute _q_arg0 = qscriptvalue_cast<Qt::ApplicationAttribute>(context->argument(0));
         QCoreApplication::setAttribute(_q_arg0);
@@ -420,7 +482,7 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 22:
+    case 21:
     if (context->argumentCount() == 1) {
         QStringList _q_arg0;
         qScriptValueToSequence(context->argument(0), _q_arg0);
@@ -429,22 +491,14 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 23:
-    if (context->argumentCount() == 1) {
-        bool _q_arg0 = context->argument(0).toBoolean();
-        QCoreApplication::setSetuidAllowed(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 24:
+    case 22:
     if (context->argumentCount() == 0) {
         bool _q_result = QCoreApplication::startingUp();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 25:
+    case 23:
     if (context->argumentCount() == 1) {
         Qt::ApplicationAttribute _q_arg0 = qscriptvalue_cast<Qt::ApplicationAttribute>(context->argument(0));
         bool _q_result = QCoreApplication::testAttribute(_q_arg0);
@@ -452,28 +506,81 @@ static QScriptValue qtscript_QCoreApplication_static_call(QScriptContext *contex
     }
     break;
 
-    case 26:
+    case 24:
     if (context->argumentCount() == 2) {
-        const char* _q_arg0 = qscriptvalue_cast<const char*>(context->argument(0));
-        const char* _q_arg1 = qscriptvalue_cast<const char*>(context->argument(1));
-        QString _q_result = QCoreApplication::translate(_q_arg0, _q_arg1);
+
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg0 = context->argument(0).toString().toLatin1();
+          const char * _q_arg0 = tmp__q_arg0.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+        
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg1 = context->argument(1).toString().toLatin1();
+          const char * _q_arg1 = tmp__q_arg1.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+                QString _q_result = QCoreApplication::translate(_q_arg0, _q_arg1);
         return QScriptValue(context->engine(), _q_result);
     }
     if (context->argumentCount() == 3) {
-        const char* _q_arg0 = qscriptvalue_cast<const char*>(context->argument(0));
-        const char* _q_arg1 = qscriptvalue_cast<const char*>(context->argument(1));
-        const char* _q_arg2 = qscriptvalue_cast<const char*>(context->argument(2));
-        QString _q_result = QCoreApplication::translate(_q_arg0, _q_arg1, _q_arg2);
+
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg0 = context->argument(0).toString().toLatin1();
+          const char * _q_arg0 = tmp__q_arg0.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+        
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg1 = context->argument(1).toString().toLatin1();
+          const char * _q_arg1 = tmp__q_arg1.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+        
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg2 = context->argument(2).toString().toLatin1();
+          const char * _q_arg2 = tmp__q_arg2.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+                QString _q_result = QCoreApplication::translate(_q_arg0, _q_arg1, _q_arg2);
         return QScriptValue(context->engine(), _q_result);
     }
     if (context->argumentCount() == 4) {
-        const char* _q_arg0 = qscriptvalue_cast<const char*>(context->argument(0));
-        const char* _q_arg1 = qscriptvalue_cast<const char*>(context->argument(1));
-        const char* _q_arg2 = qscriptvalue_cast<const char*>(context->argument(2));
-        int _q_arg3 = context->argument(3).toInt32();
+
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg0 = context->argument(0).toString().toLatin1();
+          const char * _q_arg0 = tmp__q_arg0.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+        
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg1 = context->argument(1).toString().toLatin1();
+          const char * _q_arg1 = tmp__q_arg1.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+        
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg2 = context->argument(2).toString().toLatin1();
+          const char * _q_arg2 = tmp__q_arg2.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+                QCoreApplication::Encoding _q_arg3 = qscriptvalue_cast<QCoreApplication::Encoding>(context->argument(3));
         QString _q_result = QCoreApplication::translate(_q_arg0, _q_arg1, _q_arg2, _q_arg3);
         return QScriptValue(context->engine(), _q_result);
     }
+    if (context->argumentCount() == 5) {
+
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg0 = context->argument(0).toString().toLatin1();
+          const char * _q_arg0 = tmp__q_arg0.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+        
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg1 = context->argument(1).toString().toLatin1();
+          const char * _q_arg1 = tmp__q_arg1.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+        
+          // TEMPLATE - core.convert_string_arg_to_char* - START
+          QByteArray tmp__q_arg2 = context->argument(2).toString().toLatin1();
+          const char * _q_arg2 = tmp__q_arg2.constData();
+    // TEMPLATE - core.convert_string_arg_to_char* - END
+                QCoreApplication::Encoding _q_arg3 = qscriptvalue_cast<QCoreApplication::Encoding>(context->argument(3));
+        int _q_arg4 = context->argument(4).toInt32();
+        QString _q_result = QCoreApplication::translate(_q_arg0, _q_arg1, _q_arg2, _q_arg3, _q_arg4);
+        return QScriptValue(context->engine(), _q_result);
+    }
     break;
 
     default:
@@ -500,9 +607,9 @@ QScriptValue qtscript_create_QCoreApplication_class(QScriptEngine *engine)
     QScriptValue proto = engine->newVariant(qVariantFromValue((QCoreApplication*)0));
     proto.setPrototype(engine->defaultPrototype(qMetaTypeId<QObject*>()));
     for (int i = 0; i < 2; ++i) {
-        QScriptValue fun = engine->newFunction(qtscript_QCoreApplication_prototype_call, qtscript_QCoreApplication_function_lengths[i+27]);
+        QScriptValue fun = engine->newFunction(qtscript_QCoreApplication_prototype_call, qtscript_QCoreApplication_function_lengths[i+25]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
-        proto.setProperty(QString::fromLatin1(qtscript_QCoreApplication_function_names[i+27]),
+        proto.setProperty(QString::fromLatin1(qtscript_QCoreApplication_function_names[i+25]),
             fun, QScriptValue::SkipInEnumeration);
     }
 
@@ -511,7 +618,7 @@ QScriptValue qtscript_create_QCoreApplication_class(QScriptEngine *engine)
 
     QScriptValue ctor = engine->newFunction(qtscript_QCoreApplication_static_call, proto, qtscript_QCoreApplication_function_lengths[0]);
     ctor.setData(QScriptValue(engine, uint(0xBABE0000 + 0)));
-    for (int i = 0; i < 26; ++i) {
+    for (int i = 0; i < 24; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QCoreApplication_static_call,
             qtscript_QCoreApplication_function_lengths[i+1]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i+1)));
@@ -519,5 +626,7 @@ QScriptValue qtscript_create_QCoreApplication_class(QScriptEngine *engine)
             fun, QScriptValue::SkipInEnumeration);
     }
 
+    ctor.setProperty(QString::fromLatin1("Encoding"),
+        qtscript_create_QCoreApplication_Encoding_class(engine, ctor));
     return ctor;
 }
