@@ -12,6 +12,7 @@
 #include <qdatetime.h>
 #include <qlist.h>
 #include <qlocale.h>
+#include <qstringlist.h>
 
 static const char * const qtscript_QLocale_function_names[] = {
     "QLocale"
@@ -24,17 +25,22 @@ static const char * const qtscript_QLocale_function_names[] = {
     , "system"
     // prototype
     , "amText"
+    , "bcp47Name"
     , "country"
+    , "createSeparatedList"
     , "dateFormat"
     , "dateTimeFormat"
     , "dayName"
     , "decimalPoint"
     , "exponential"
+    , "firstDayOfWeek"
     , "groupSeparator"
     , "language"
     , "measurementSystem"
     , "monthName"
     , "name"
+    , "nativeCountryName"
+    , "nativeLanguageName"
     , "negativeSign"
     , "numberOptions"
     , "equals"
@@ -47,16 +53,21 @@ static const char * const qtscript_QLocale_function_names[] = {
     , "standaloneMonthName"
     , "textDirection"
     , "timeFormat"
+    , "toCurrencyString"
     , "toDate"
     , "toDateTime"
     , "toDouble"
     , "toFloat"
     , "toInt"
     , "toLongLong"
+    , "toLower"
     , "toShort"
     , "toString"
     , "toTime"
     , "toUShort"
+    , "toUpper"
+    , "uiLanguages"
+    , "weekdays"
     , "writeTo"
     , "zeroDigit"
 };
@@ -73,6 +84,8 @@ static const char * const qtscript_QLocale_function_signatures[] = {
     // prototype
     , ""
     , ""
+    , ""
+    , "List strl"
     , "FormatType format"
     , "FormatType format"
     , "int arg__1, FormatType format"
@@ -81,10 +94,13 @@ static const char * const qtscript_QLocale_function_signatures[] = {
     , ""
     , ""
     , ""
+    , ""
     , "int arg__1, FormatType format"
     , ""
     , ""
     , ""
+    , ""
+    , ""
     , "QLocale other"
     , ""
     , ""
@@ -95,16 +111,21 @@ static const char * const qtscript_QLocale_function_signatures[] = {
     , "int arg__1, FormatType format"
     , ""
     , "FormatType format"
+    , "double arg__1, String symbol\nfloat arg__1, String symbol\nint arg__1, String symbol\nqlonglong arg__1, String symbol\nqulonglong arg__1, String symbol\nshort arg__1, String symbol\nuint arg__1, String symbol\nushort arg__1, String symbol"
     , "String string, FormatType arg__2\nString string, String format"
     , "String string, FormatType format\nString string, String format"
     , "String s"
     , "String s"
     , "String s, int base"
     , "String s, int base"
+    , "String str"
     , "String s, int base"
     , "QDate date, FormatType format\nQDate date, String formatStr\nQDateTime dateTime, FormatType format\nQDateTime dateTime, String format\nQTime time, FormatType format\nQTime time, String formatStr\ndouble i, char f, int prec\nfloat i, char f, int prec\nint i\nqulonglong i\nshort i"
     , "String string, FormatType arg__2\nString string, String format"
     , "String s, int base"
+    , "String str"
+    , ""
+    , ""
     , "QDataStream arg__1"
     , ""
 };
@@ -121,6 +142,8 @@ static const int qtscript_QLocale_function_lengths[] = {
     // prototype
     , 0
     , 0
+    , 0
+    , 1
     , 1
     , 1
     , 2
@@ -129,10 +152,13 @@ static const int qtscript_QLocale_function_lengths[] = {
     , 0
     , 0
     , 0
+    , 0
     , 2
     , 0
     , 0
     , 0
+    , 0
+    , 0
     , 1
     , 0
     , 0
@@ -147,14 +173,19 @@ static const int qtscript_QLocale_function_lengths[] = {
     , 2
     , 2
     , 2
+    , 2
     , 3
     , 3
+    , 1
     , 3
     , 3
     , 2
     , 3
     , 1
     , 0
+    , 0
+    , 1
+    , 0
 };
 
 static QScriptValue qtscript_QLocale_throw_ambiguity_error_helper(
@@ -180,8 +211,10 @@ Q_DECLARE_METATYPE(QFlags<QLocale::NumberOption>)
 Q_DECLARE_METATYPE(QLocale::FormatType)
 Q_DECLARE_METATYPE(QLocale::Country)
 Q_DECLARE_METATYPE(QLocale::Language)
+Q_DECLARE_METATYPE(Qt::DayOfWeek)
 Q_DECLARE_METATYPE(QDataStream*)
 Q_DECLARE_METATYPE(Qt::LayoutDirection)
+Q_DECLARE_METATYPE(QList<Qt::DayOfWeek>)
 Q_DECLARE_METATYPE(QList<QLocale::Country>)
 
 
@@ -1065,7 +1098,8 @@ static QScriptValue qtscript_create_QLocale_Country_class(QScriptEngine *engine,
 //
 
 static const QLocale::Language qtscript_QLocale_Language_values[] = {
-    QLocale::C
+    QLocale::AnyLanguage
+    , QLocale::C
     , QLocale::Abkhazian
     , QLocale::Afan
     , QLocale::Afar
@@ -1132,7 +1166,7 @@ static const QLocale::Language qtscript_QLocale_Language_values[] = {
     , QLocale::Kirghiz
     , QLocale::Korean
     , QLocale::Kurdish
-    , QLocale::Kurundi
+    , QLocale::Rundi
     , QLocale::Laothian
     , QLocale::Latin
     , QLocale::Latvian
@@ -1205,7 +1239,7 @@ static const QLocale::Language qtscript_QLocale_Language_values[] = {
     , QLocale::Yoruba
     , QLocale::Zhuang
     , QLocale::Zulu
-    , QLocale::NorwegianNynorsk
+    , QLocale::Nynorsk
     , QLocale::Bosnian
     , QLocale::Divehi
     , QLocale::Manx
@@ -1279,10 +1313,31 @@ static const QLocale::Language qtscript_QLocale_Language_values[] = {
     , QLocale::CentralMoroccoTamazight
     , QLocale::KoyraboroSenni
     , QLocale::Shambala
+    , QLocale::Bodo
+    , QLocale::Aghem
+    , QLocale::Basaa
+    , QLocale::Zarma
+    , QLocale::Duala
+    , QLocale::JolaFonyi
+    , QLocale::Ewondo
+    , QLocale::Bafia
+    , QLocale::LubaKatanga
+    , QLocale::MakhuwaMeetto
+    , QLocale::Mundang
+    , QLocale::Kwasio
+    , QLocale::Nuer
+    , QLocale::Sakha
+    , QLocale::Sangu
+    , QLocale::CongoSwahili
+    , QLocale::Tasawaq
+    , QLocale::Vai
+    , QLocale::Walser
+    , QLocale::Yangben
 };
 
 static const char * const qtscript_QLocale_Language_keys[] = {
-    "C"
+    "AnyLanguage"
+    , "C"
     , "Abkhazian"
     , "Afan"
     , "Afar"
@@ -1349,7 +1404,7 @@ static const char * const qtscript_QLocale_Language_keys[] = {
     , "Kirghiz"
     , "Korean"
     , "Kurdish"
-    , "Kurundi"
+    , "Rundi"
     , "Laothian"
     , "Latin"
     , "Latvian"
@@ -1422,7 +1477,7 @@ static const char * const qtscript_QLocale_Language_keys[] = {
     , "Yoruba"
     , "Zhuang"
     , "Zulu"
-    , "NorwegianNynorsk"
+    , "Nynorsk"
     , "Bosnian"
     , "Divehi"
     , "Manx"
@@ -1496,6 +1551,26 @@ static const char * const qtscript_QLocale_Language_keys[] = {
     , "CentralMoroccoTamazight"
     , "KoyraboroSenni"
     , "Shambala"
+    , "Bodo"
+    , "Aghem"
+    , "Basaa"
+    , "Zarma"
+    , "Duala"
+    , "JolaFonyi"
+    , "Ewondo"
+    , "Bafia"
+    , "LubaKatanga"
+    , "MakhuwaMeetto"
+    , "Mundang"
+    , "Kwasio"
+    , "Nuer"
+    , "Sakha"
+    , "Sangu"
+    , "CongoSwahili"
+    , "Tasawaq"
+    , "Vai"
+    , "Walser"
+    , "Yangben"
 };
 
 static QString qtscript_QLocale_Language_toStringHelper(QLocale::Language value)
@@ -1549,7 +1624,7 @@ static QScriptValue qtscript_create_QLocale_Language_class(QScriptEngine *engine
         qtscript_QLocale_Language_valueOf, qtscript_QLocale_Language_toString);
     qScriptRegisterMetaType<QLocale::Language>(engine, qtscript_QLocale_Language_toScriptValue,
         qtscript_QLocale_Language_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 214; ++i) {
+    for (int i = 0; i < 235; ++i) {
         clazz.setProperty(QString::fromLatin1(qtscript_QLocale_Language_keys[i]),
             engine->newVariant(qVariantFromValue(qtscript_QLocale_Language_values[i])),
             QScriptValue::ReadOnly | QScriptValue::Undeletable);
@@ -1571,7 +1646,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 36;
+        _id = 0xBABE0000 + 46;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -1591,13 +1666,29 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     break;
 
     case 1:
+    if (context->argumentCount() == 0) {
+        QString _q_result = _q_self->bcp47Name();
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 2:
     if (context->argumentCount() == 0) {
         QLocale::Country _q_result = _q_self->country();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 2:
+    case 3:
+    if (context->argumentCount() == 1) {
+        QStringList _q_arg0;
+        qScriptValueToSequence(context->argument(0), _q_arg0);
+        QString _q_result = _q_self->createSeparatedList(_q_arg0);
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 4:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->dateFormat();
         return QScriptValue(context->engine(), _q_result);
@@ -1609,7 +1700,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 3:
+    case 5:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->dateTimeFormat();
         return QScriptValue(context->engine(), _q_result);
@@ -1621,7 +1712,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 4:
+    case 6:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         QString _q_result = _q_self->dayName(_q_arg0);
@@ -1635,42 +1726,49 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 5:
+    case 7:
     if (context->argumentCount() == 0) {
         QChar _q_result = _q_self->decimalPoint();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 6:
+    case 8:
     if (context->argumentCount() == 0) {
         QChar _q_result = _q_self->exponential();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 7:
+    case 9:
+    if (context->argumentCount() == 0) {
+        Qt::DayOfWeek _q_result = _q_self->firstDayOfWeek();
+        return qScriptValueFromValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 10:
     if (context->argumentCount() == 0) {
         QChar _q_result = _q_self->groupSeparator();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 8:
+    case 11:
     if (context->argumentCount() == 0) {
         QLocale::Language _q_result = _q_self->language();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 9:
+    case 12:
     if (context->argumentCount() == 0) {
         QLocale::MeasurementSystem _q_result = _q_self->measurementSystem();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 10:
+    case 13:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         QString _q_result = _q_self->monthName(_q_arg0);
@@ -1684,28 +1782,42 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 11:
+    case 14:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->name();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 12:
+    case 15:
+    if (context->argumentCount() == 0) {
+        QString _q_result = _q_self->nativeCountryName();
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 16:
+    if (context->argumentCount() == 0) {
+        QString _q_result = _q_self->nativeLanguageName();
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 17:
     if (context->argumentCount() == 0) {
         QChar _q_result = _q_self->negativeSign();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 13:
+    case 18:
     if (context->argumentCount() == 0) {
         QFlags<QLocale::NumberOption> _q_result = _q_self->numberOptions();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 14:
+    case 19:
     if (context->argumentCount() == 1) {
         QLocale _q_arg0 = qscriptvalue_cast<QLocale>(context->argument(0));
         bool _q_result = _q_self->operator==(_q_arg0);
@@ -1713,28 +1825,28 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 15:
+    case 20:
     if (context->argumentCount() == 0) {
         QChar _q_result = _q_self->percent();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 16:
+    case 21:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->pmText();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 17:
+    case 22:
     if (context->argumentCount() == 0) {
         QChar _q_result = _q_self->positiveSign();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 18:
+    case 23:
     if (context->argumentCount() == 1) {
         QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
         operator>>(*_q_arg0, *_q_self);
@@ -1742,7 +1854,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 19:
+    case 24:
     if (context->argumentCount() == 1) {
         QFlags<QLocale::NumberOption> _q_arg0 = qscriptvalue_cast<QFlags<QLocale::NumberOption> >(context->argument(0));
         _q_self->setNumberOptions(_q_arg0);
@@ -1750,7 +1862,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 20:
+    case 25:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         QString _q_result = _q_self->standaloneDayName(_q_arg0);
@@ -1764,7 +1876,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 21:
+    case 26:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         QString _q_result = _q_self->standaloneMonthName(_q_arg0);
@@ -1778,14 +1890,14 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 22:
+    case 27:
     if (context->argumentCount() == 0) {
         Qt::LayoutDirection _q_result = _q_self->textDirection();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 23:
+    case 28:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->timeFormat();
         return QScriptValue(context->engine(), _q_result);
@@ -1797,7 +1909,96 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 24:
+    case 29:
+    if (context->argumentCount() == 1) {
+        if (context->argument(0).isNumber()) {
+            double _q_arg0 = context->argument(0).toNumber();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0);
+            return QScriptValue(context->engine(), _q_result);
+        } else if (context->argument(0).isNumber()) {
+            float _q_arg0 = qscriptvalue_cast<float>(context->argument(0));
+            QString _q_result = _q_self->toCurrencyString(_q_arg0);
+            return QScriptValue(context->engine(), _q_result);
+        } else if (context->argument(0).isNumber()) {
+            int _q_arg0 = context->argument(0).toInt32();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0);
+            return QScriptValue(context->engine(), _q_result);
+        } else if ((qMetaTypeId<qlonglong>() == context->argument(0).toVariant().userType())) {
+            qlonglong _q_arg0 = qscriptvalue_cast<qlonglong>(context->argument(0));
+            QString _q_result = _q_self->toCurrencyString(_q_arg0);
+            return QScriptValue(context->engine(), _q_result);
+        } else if ((qMetaTypeId<qulonglong>() == context->argument(0).toVariant().userType())) {
+            qulonglong _q_arg0 = qscriptvalue_cast<qulonglong>(context->argument(0));
+            QString _q_result = _q_self->toCurrencyString(_q_arg0);
+            return QScriptValue(context->engine(), _q_result);
+        } else if (context->argument(0).isNumber()) {
+            short _q_arg0 = qscriptvalue_cast<short>(context->argument(0));
+            QString _q_result = _q_self->toCurrencyString(_q_arg0);
+            return QScriptValue(context->engine(), _q_result);
+        } else if (context->argument(0).isNumber()) {
+            uint _q_arg0 = context->argument(0).toUInt32();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0);
+            return QScriptValue(context->engine(), _q_result);
+        } else if ((qMetaTypeId<ushort>() == context->argument(0).toVariant().userType())) {
+            ushort _q_arg0 = qscriptvalue_cast<ushort>(context->argument(0));
+            QString _q_result = _q_self->toCurrencyString(_q_arg0);
+            return QScriptValue(context->engine(), _q_result);
+        }
+    }
+    if (context->argumentCount() == 2) {
+        if (context->argument(0).isNumber()
+            && context->argument(1).isString()) {
+            double _q_arg0 = context->argument(0).toNumber();
+            QString _q_arg1 = context->argument(1).toString();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0, _q_arg1);
+            return QScriptValue(context->engine(), _q_result);
+        } else if (context->argument(0).isNumber()
+            && context->argument(1).isString()) {
+            float _q_arg0 = qscriptvalue_cast<float>(context->argument(0));
+            QString _q_arg1 = context->argument(1).toString();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0, _q_arg1);
+            return QScriptValue(context->engine(), _q_result);
+        } else if (context->argument(0).isNumber()
+            && context->argument(1).isString()) {
+            int _q_arg0 = context->argument(0).toInt32();
+            QString _q_arg1 = context->argument(1).toString();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0, _q_arg1);
+            return QScriptValue(context->engine(), _q_result);
+        } else if ((qMetaTypeId<qlonglong>() == context->argument(0).toVariant().userType())
+            && context->argument(1).isString()) {
+            qlonglong _q_arg0 = qscriptvalue_cast<qlonglong>(context->argument(0));
+            QString _q_arg1 = context->argument(1).toString();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0, _q_arg1);
+            return QScriptValue(context->engine(), _q_result);
+        } else if ((qMetaTypeId<qulonglong>() == context->argument(0).toVariant().userType())
+            && context->argument(1).isString()) {
+            qulonglong _q_arg0 = qscriptvalue_cast<qulonglong>(context->argument(0));
+            QString _q_arg1 = context->argument(1).toString();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0, _q_arg1);
+            return QScriptValue(context->engine(), _q_result);
+        } else if (context->argument(0).isNumber()
+            && context->argument(1).isString()) {
+            short _q_arg0 = qscriptvalue_cast<short>(context->argument(0));
+            QString _q_arg1 = context->argument(1).toString();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0, _q_arg1);
+            return QScriptValue(context->engine(), _q_result);
+        } else if (context->argument(0).isNumber()
+            && context->argument(1).isString()) {
+            uint _q_arg0 = context->argument(0).toUInt32();
+            QString _q_arg1 = context->argument(1).toString();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0, _q_arg1);
+            return QScriptValue(context->engine(), _q_result);
+        } else if ((qMetaTypeId<ushort>() == context->argument(0).toVariant().userType())
+            && context->argument(1).isString()) {
+            ushort _q_arg0 = qscriptvalue_cast<ushort>(context->argument(0));
+            QString _q_arg1 = context->argument(1).toString();
+            QString _q_result = _q_self->toCurrencyString(_q_arg0, _q_arg1);
+            return QScriptValue(context->engine(), _q_result);
+        }
+    }
+    break;
+
+    case 30:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         QDate _q_result = _q_self->toDate(_q_arg0);
@@ -1820,7 +2021,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 25:
+    case 31:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         QDateTime _q_result = _q_self->toDateTime(_q_arg0);
@@ -1843,7 +2044,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 26:
+    case 32:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
 
@@ -1864,7 +2065,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 27:
+    case 33:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
 
@@ -1885,7 +2086,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 28:
+    case 34:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
 
@@ -1925,7 +2126,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 29:
+    case 35:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
 
@@ -1961,7 +2162,15 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 30:
+    case 36:
+    if (context->argumentCount() == 1) {
+        QString _q_arg0 = context->argument(0).toString();
+        QString _q_result = _q_self->toLower(_q_arg0);
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 37:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
 
@@ -2001,7 +2210,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 31:
+    case 38:
     if (context->argumentCount() == 1) {
         if ((qMetaTypeId<QDate>() == context->argument(0).toVariant().userType())) {
             QDate _q_arg0 = qscriptvalue_cast<QDate>(context->argument(0));
@@ -2109,7 +2318,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 32:
+    case 39:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         QTime _q_result = _q_self->toTime(_q_arg0);
@@ -2132,7 +2341,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 33:
+    case 40:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
 
@@ -2172,7 +2381,29 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 34:
+    case 41:
+    if (context->argumentCount() == 1) {
+        QString _q_arg0 = context->argument(0).toString();
+        QString _q_result = _q_self->toUpper(_q_arg0);
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 42:
+    if (context->argumentCount() == 0) {
+        QStringList _q_result = _q_self->uiLanguages();
+        return qScriptValueFromSequence(context->engine(), _q_result);
+    }
+    break;
+
+    case 43:
+    if (context->argumentCount() == 0) {
+        QList<Qt::DayOfWeek> _q_result = _q_self->weekdays();
+        return qScriptValueFromSequence(context->engine(), _q_result);
+    }
+    break;
+
+    case 44:
     if (context->argumentCount() == 1) {
         QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
         operator<<(*_q_arg0, *_q_self);
@@ -2180,7 +2411,7 @@ static QScriptValue qtscript_QLocale_prototype_call(QScriptContext *context, QSc
     }
     break;
 
-    case 35:
+    case 45:
     if (context->argumentCount() == 0) {
         QChar _q_result = _q_self->zeroDigit();
         return qScriptValueFromValue(context->engine(), _q_result);
@@ -2293,7 +2524,7 @@ QScriptValue qtscript_create_QLocale_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QLocale*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QLocale*)0));
-    for (int i = 0; i < 36; ++i) {
+    for (int i = 0; i < 46; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QLocale_prototype_call, qtscript_QLocale_function_lengths[i+7]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QLocale_function_names[i+7]),
