@@ -4,11 +4,11 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
-#include <__package_shared.h>
 
 #include <quuid.h>
 #include <QVariant>
 #include <qbytearray.h>
+#include <qdatastream.h>
 #include <quuid.h>
 
 #include "qtscriptshell_QUuid.h"
@@ -17,54 +17,54 @@ static const char * const qtscript_QUuid_function_names[] = {
     "QUuid"
     // static
     , "createUuid"
-    , "createUuidV3"
-    , "createUuidV5"
     , "fromRfc4122"
     // prototype
     , "isNull"
     , "equals"
     , "operator_less"
+    , "readFrom"
     , "toByteArray"
     , "toRfc4122"
     , "toString"
     , "variant"
     , "version"
+    , "writeTo"
 };
 
 static const char * const qtscript_QUuid_function_signatures[] = {
     "\nQByteArray arg__1\nString arg__1\nuint l, ushort w1, ushort w2, uchar b1, uchar b2, uchar b3, uchar b4, uchar b5, uchar b6, uchar b7, uchar b8"
     // static
     , ""
-    , "QUuid ns, QByteArray baseData\nQUuid ns, String baseData"
-    , "QUuid ns, QByteArray baseData\nQUuid ns, String baseData"
     , "QByteArray arg__1"
     // prototype
     , ""
     , "QUuid orig"
     , "QUuid other"
+    , "QDataStream arg__1"
     , ""
     , ""
     , ""
     , ""
     , ""
+    , "QDataStream arg__1"
 };
 
 static const int qtscript_QUuid_function_lengths[] = {
     11
     // static
     , 0
-    , 2
-    , 2
     , 1
     // prototype
     , 0
     , 1
     , 1
+    , 1
     , 0
     , 0
     , 0
     , 0
     , 0
+    , 1
 };
 
 static QScriptValue qtscript_QUuid_throw_ambiguity_error_helper(
@@ -78,11 +78,13 @@ static QScriptValue qtscript_QUuid_throw_ambiguity_error_helper(
         .arg(functionName).arg(fullSignatures.join(QLatin1String("\n"))));
 }
 
+Q_DECLARE_METATYPE(QUuid)
 Q_DECLARE_METATYPE(QUuid*)
 Q_DECLARE_METATYPE(QtScriptShell_QUuid)
 Q_DECLARE_METATYPE(QtScriptShell_QUuid*)
-Q_DECLARE_METATYPE(QUuid::Version)
 Q_DECLARE_METATYPE(QUuid::Variant)
+Q_DECLARE_METATYPE(QUuid::Version)
+Q_DECLARE_METATYPE(QDataStream*)
 
 static QScriptValue qtscript_create_enum_class_helper(
     QScriptEngine *engine,
@@ -98,85 +100,6 @@ static QScriptValue qtscript_create_enum_class_helper(
     return engine->newFunction(construct, proto, 1);
 }
 
-//
-// QUuid::Version
-//
-
-static const QUuid::Version qtscript_QUuid_Version_values[] = {
-    QUuid::VerUnknown
-    , QUuid::Time
-    , QUuid::EmbeddedPOSIX
-    , QUuid::Md5
-    , QUuid::Random
-    , QUuid::Sha1
-};
-
-static const char * const qtscript_QUuid_Version_keys[] = {
-    "VerUnknown"
-    , "Time"
-    , "EmbeddedPOSIX"
-    , "Md5"
-    , "Random"
-    , "Sha1"
-};
-
-static QString qtscript_QUuid_Version_toStringHelper(QUuid::Version value)
-{
-    for (int i = 0; i < 6; ++i) {
-        if (qtscript_QUuid_Version_values[i] == value)
-            return QString::fromLatin1(qtscript_QUuid_Version_keys[i]);
-    }
-    return QString();
-}
-
-static QScriptValue qtscript_QUuid_Version_toScriptValue(QScriptEngine *engine, const QUuid::Version &value)
-{
-    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QUuid"));
-    return clazz.property(qtscript_QUuid_Version_toStringHelper(value));
-}
-
-static void qtscript_QUuid_Version_fromScriptValue(const QScriptValue &value, QUuid::Version &out)
-{
-    out = qvariant_cast<QUuid::Version>(value.toVariant());
-}
-
-static QScriptValue qtscript_construct_QUuid_Version(QScriptContext *context, QScriptEngine *engine)
-{
-    int arg = context->argument(0).toInt32();
-    for (int i = 0; i < 6; ++i) {
-        if (qtscript_QUuid_Version_values[i] == arg)
-            return qScriptValueFromValue(engine,  static_cast<QUuid::Version>(arg));
-    }
-    return context->throwError(QString::fromLatin1("Version(): invalid enum value (%0)").arg(arg));
-}
-
-static QScriptValue qtscript_QUuid_Version_valueOf(QScriptContext *context, QScriptEngine *engine)
-{
-    QUuid::Version value = qscriptvalue_cast<QUuid::Version>(context->thisObject());
-    return QScriptValue(engine, static_cast<int>(value));
-}
-
-static QScriptValue qtscript_QUuid_Version_toString(QScriptContext *context, QScriptEngine *engine)
-{
-    QUuid::Version value = qscriptvalue_cast<QUuid::Version>(context->thisObject());
-    return QScriptValue(engine, qtscript_QUuid_Version_toStringHelper(value));
-}
-
-static QScriptValue qtscript_create_QUuid_Version_class(QScriptEngine *engine, QScriptValue &clazz)
-{
-    QScriptValue ctor = qtscript_create_enum_class_helper(
-        engine, qtscript_construct_QUuid_Version,
-        qtscript_QUuid_Version_valueOf, qtscript_QUuid_Version_toString);
-    qScriptRegisterMetaType<QUuid::Version>(engine, qtscript_QUuid_Version_toScriptValue,
-        qtscript_QUuid_Version_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 6; ++i) {
-        clazz.setProperty(QString::fromLatin1(qtscript_QUuid_Version_keys[i]),
-            engine->newVariant(qVariantFromValue(qtscript_QUuid_Version_values[i])),
-            QScriptValue::ReadOnly | QScriptValue::Undeletable);
-    }
-    return ctor;
-}
-
 //
 // QUuid::Variant
 //
@@ -254,6 +177,83 @@ static QScriptValue qtscript_create_QUuid_Variant_class(QScriptEngine *engine, Q
     return ctor;
 }
 
+//
+// QUuid::Version
+//
+
+static const QUuid::Version qtscript_QUuid_Version_values[] = {
+    QUuid::VerUnknown
+    , QUuid::Time
+    , QUuid::EmbeddedPOSIX
+    , QUuid::Name
+    , QUuid::Random
+};
+
+static const char * const qtscript_QUuid_Version_keys[] = {
+    "VerUnknown"
+    , "Time"
+    , "EmbeddedPOSIX"
+    , "Name"
+    , "Random"
+};
+
+static QString qtscript_QUuid_Version_toStringHelper(QUuid::Version value)
+{
+    for (int i = 0; i < 5; ++i) {
+        if (qtscript_QUuid_Version_values[i] == value)
+            return QString::fromLatin1(qtscript_QUuid_Version_keys[i]);
+    }
+    return QString();
+}
+
+static QScriptValue qtscript_QUuid_Version_toScriptValue(QScriptEngine *engine, const QUuid::Version &value)
+{
+    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QUuid"));
+    return clazz.property(qtscript_QUuid_Version_toStringHelper(value));
+}
+
+static void qtscript_QUuid_Version_fromScriptValue(const QScriptValue &value, QUuid::Version &out)
+{
+    out = qvariant_cast<QUuid::Version>(value.toVariant());
+}
+
+static QScriptValue qtscript_construct_QUuid_Version(QScriptContext *context, QScriptEngine *engine)
+{
+    int arg = context->argument(0).toInt32();
+    for (int i = 0; i < 5; ++i) {
+        if (qtscript_QUuid_Version_values[i] == arg)
+            return qScriptValueFromValue(engine,  static_cast<QUuid::Version>(arg));
+    }
+    return context->throwError(QString::fromLatin1("Version(): invalid enum value (%0)").arg(arg));
+}
+
+static QScriptValue qtscript_QUuid_Version_valueOf(QScriptContext *context, QScriptEngine *engine)
+{
+    QUuid::Version value = qscriptvalue_cast<QUuid::Version>(context->thisObject());
+    return QScriptValue(engine, static_cast<int>(value));
+}
+
+static QScriptValue qtscript_QUuid_Version_toString(QScriptContext *context, QScriptEngine *engine)
+{
+    QUuid::Version value = qscriptvalue_cast<QUuid::Version>(context->thisObject());
+    return QScriptValue(engine, qtscript_QUuid_Version_toStringHelper(value));
+}
+
+static QScriptValue qtscript_create_QUuid_Version_class(QScriptEngine *engine, QScriptValue &clazz)
+{
+    QScriptValue ctor = qtscript_create_enum_class_helper(
+        engine, qtscript_construct_QUuid_Version,
+        qtscript_QUuid_Version_valueOf, qtscript_QUuid_Version_toString);
+    qScriptRegisterMetaType<QUuid::Version>(engine, qtscript_QUuid_Version_toScriptValue,
+        qtscript_QUuid_Version_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
+    for (int i = 0; i < 5; ++i) {
+        clazz.setProperty(QString::fromLatin1(qtscript_QUuid_Version_keys[i]),
+            engine->newVariant(qVariantFromValue(qtscript_QUuid_Version_values[i])),
+            QScriptValue::ReadOnly | QScriptValue::Undeletable);
+    }
+    return ctor;
+}
+
 //
 // QUuid
 //
@@ -268,7 +268,7 @@ static QScriptValue qtscript_QUuid_prototype_call(QScriptContext *context, QScri
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 8;
+        _id = 0xBABE0000 + 10;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -276,7 +276,7 @@ static QScriptValue qtscript_QUuid_prototype_call(QScriptContext *context, QScri
     if (!_q_self) {
         return context->throwError(QScriptContext::TypeError,
             QString::fromLatin1("QUuid.%0(): this object is not a QUuid")
-            .arg(qtscript_QUuid_function_names[_id+5]));
+            .arg(qtscript_QUuid_function_names[_id+3]));
     }
 
     switch (_id) {
@@ -304,46 +304,62 @@ static QScriptValue qtscript_QUuid_prototype_call(QScriptContext *context, QScri
     break;
 
     case 3:
+    if (context->argumentCount() == 1) {
+        QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
+        operator>>(*_q_arg0, *_q_self);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 4:
     if (context->argumentCount() == 0) {
         QByteArray _q_result = _q_self->toByteArray();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 4:
+    case 5:
     if (context->argumentCount() == 0) {
         QByteArray _q_result = _q_self->toRfc4122();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 5:
+    case 6:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->toString();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 6:
+    case 7:
     if (context->argumentCount() == 0) {
         QUuid::Variant _q_result = _q_self->variant();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 7:
+    case 8:
     if (context->argumentCount() == 0) {
         QUuid::Version _q_result = _q_self->version();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
+    case 9:
+    if (context->argumentCount() == 1) {
+        QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
+        operator<<(*_q_arg0, *_q_self);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
     default:
     Q_ASSERT(false);
     }
     return qtscript_QUuid_throw_ambiguity_error_helper(context,
-        qtscript_QUuid_function_names[_id+5],
-        qtscript_QUuid_function_signatures[_id+5]);
+        qtscript_QUuid_function_names[_id+3],
+        qtscript_QUuid_function_signatures[_id+3]);
 }
 
 static QScriptValue qtscript_QUuid_static_call(QScriptContext *context, QScriptEngine *)
@@ -402,42 +418,6 @@ static QScriptValue qtscript_QUuid_static_call(QScriptContext *context, QScriptE
     break;
 
     case 2:
-    if (context->argumentCount() == 2) {
-        if ((qMetaTypeId<QUuid>() == context->argument(0).toVariant().userType())
-            && (qMetaTypeId<QByteArray>() == context->argument(1).toVariant().userType())) {
-            QUuid _q_arg0 = qscriptvalue_cast<QUuid>(context->argument(0));
-            QByteArray _q_arg1 = qscriptvalue_cast<QByteArray>(context->argument(1));
-            QUuid _q_result = QUuid::createUuidV3(_q_arg0, _q_arg1);
-            return qScriptValueFromValue(context->engine(), _q_result);
-        } else if ((qMetaTypeId<QUuid>() == context->argument(0).toVariant().userType())
-            && context->argument(1).isString()) {
-            QUuid _q_arg0 = qscriptvalue_cast<QUuid>(context->argument(0));
-            QString _q_arg1 = context->argument(1).toString();
-            QUuid _q_result = QUuid::createUuidV3(_q_arg0, _q_arg1);
-            return qScriptValueFromValue(context->engine(), _q_result);
-        }
-    }
-    break;
-
-    case 3:
-    if (context->argumentCount() == 2) {
-        if ((qMetaTypeId<QUuid>() == context->argument(0).toVariant().userType())
-            && (qMetaTypeId<QByteArray>() == context->argument(1).toVariant().userType())) {
-            QUuid _q_arg0 = qscriptvalue_cast<QUuid>(context->argument(0));
-            QByteArray _q_arg1 = qscriptvalue_cast<QByteArray>(context->argument(1));
-            QUuid _q_result = QUuid::createUuidV5(_q_arg0, _q_arg1);
-            return qScriptValueFromValue(context->engine(), _q_result);
-        } else if ((qMetaTypeId<QUuid>() == context->argument(0).toVariant().userType())
-            && context->argument(1).isString()) {
-            QUuid _q_arg0 = qscriptvalue_cast<QUuid>(context->argument(0));
-            QString _q_arg1 = context->argument(1).toString();
-            QUuid _q_result = QUuid::createUuidV5(_q_arg0, _q_arg1);
-            return qScriptValueFromValue(context->engine(), _q_result);
-        }
-    }
-    break;
-
-    case 4:
     if (context->argumentCount() == 1) {
         QByteArray _q_arg0 = qscriptvalue_cast<QByteArray>(context->argument(0));
         QUuid _q_result = QUuid::fromRfc4122(_q_arg0);
@@ -457,10 +437,10 @@ QScriptValue qtscript_create_QUuid_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QUuid*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QUuid*)0));
-    for (int i = 0; i < 8; ++i) {
-        QScriptValue fun = engine->newFunction(qtscript_QUuid_prototype_call, qtscript_QUuid_function_lengths[i+5]);
+    for (int i = 0; i < 10; ++i) {
+        QScriptValue fun = engine->newFunction(qtscript_QUuid_prototype_call, qtscript_QUuid_function_lengths[i+3]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
-        proto.setProperty(QString::fromLatin1(qtscript_QUuid_function_names[i+5]),
+        proto.setProperty(QString::fromLatin1(qtscript_QUuid_function_names[i+3]),
             fun, QScriptValue::SkipInEnumeration);
     }
 
@@ -469,7 +449,7 @@ QScriptValue qtscript_create_QUuid_class(QScriptEngine *engine)
 
     QScriptValue ctor = engine->newFunction(qtscript_QUuid_static_call, proto, qtscript_QUuid_function_lengths[0]);
     ctor.setData(QScriptValue(engine, uint(0xBABE0000 + 0)));
-    for (int i = 0; i < 4; ++i) {
+    for (int i = 0; i < 2; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QUuid_static_call,
             qtscript_QUuid_function_lengths[i+1]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i+1)));
@@ -477,9 +457,9 @@ QScriptValue qtscript_create_QUuid_class(QScriptEngine *engine)
             fun, QScriptValue::SkipInEnumeration);
     }
 
-    ctor.setProperty(QString::fromLatin1("Version"),
-        qtscript_create_QUuid_Version_class(engine, ctor));
     ctor.setProperty(QString::fromLatin1("Variant"),
         qtscript_create_QUuid_Variant_class(engine, ctor));
+    ctor.setProperty(QString::fromLatin1("Version"),
+        qtscript_create_QUuid_Version_class(engine, ctor));
     return ctor;
 }
