@@ -4,13 +4,12 @@
 #include <qsignaltransition.h>
 
 #include <QtScript/qscriptvalue.h>
-#include <__package_shared.h>
 
 class QtScriptShell_QSignalTransition : public QSignalTransition
 {
 public:
+    QtScriptShell_QSignalTransition(QObject*  sender, const char*  signal, QState*  sourceState = 0);
     QtScriptShell_QSignalTransition(QState*  sourceState = 0);
-    QtScriptShell_QSignalTransition(const QObject*  sender, const char*  signal, QState*  sourceState = 0);
     ~QtScriptShell_QSignalTransition();
 
     void childEvent(QChildEvent*  arg__1);
