@@ -1,7 +1,6 @@
 #include "qtscriptshell_QMainWindow.h"
 
 #include <QtScript/QScriptEngine>
-#include <QDebug>
 #include <QVariant>
 #include <qaction.h>
 #include <qbitmap.h>
@@ -482,22 +481,16 @@ void QtScriptShell_QMainWindow::mouseMoveEvent(QMouseEvent*  arg__1)
 
 void QtScriptShell_QMainWindow::mousePressEvent(QMouseEvent*  arg__1)
 {
-    qDebug() << "QtScriptShell_QMainWindow::mousePressEvent";
     QScriptValue _q_function = __qtscript_self.property("mousePressEvent");
     if (!_q_function.isFunction() || QTSCRIPT_IS_GENERATED_FUNCTION(_q_function)
         || (__qtscript_self.propertyFlags("mousePressEvent") & QScriptValue::QObjectMember)) {
-        qDebug() << "QtScriptShell_QMainWindow::mousePressEvent: calling base class";
         QMainWindow::mousePressEvent(arg__1);
-        qDebug() << "QtScriptShell_QMainWindow::mousePressEvent: calling base class: done";
     } else {
-        qDebug() << "QtScriptShell_QMainWindow::mousePressEvent: calling JS";
         QScriptEngine *_q_engine = __qtscript_self.engine();
         _q_function.call(__qtscript_self,
             QScriptValueList()
             << qScriptValueFromValue(_q_engine, arg__1));
-        qDebug() << "QtScriptShell_QMainWindow::mousePressEvent: calling JS: done";
     }
-    qDebug() << "QtScriptShell_QMainWindow::mousePressEvent: done";
 }
 
 void QtScriptShell_QMainWindow::mouseReleaseEvent(QMouseEvent*  arg__1)
