@@ -4,6 +4,7 @@
 #include <qglpixelbuffer.h>
 
 #include <QtScript/qscriptvalue.h>
+#include <__package_shared.h>
 
 class QtScriptShell_QGLPixelBuffer : public QGLPixelBuffer
 {
@@ -13,8 +14,11 @@ public:
     ~QtScriptShell_QGLPixelBuffer();
 
     int  devType() const;
+    void initPainter(QPainter*  painter) const;
     int  metric(QPaintDevice::PaintDeviceMetric  metric) const;
     QPaintEngine*  paintEngine() const;
+    QPaintDevice*  redirected(QPoint*  offset) const;
+    QPainter*  sharedPainter() const;
 
     QScriptValue __qtscript_self;
 };
