@@ -4,12 +4,12 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
+#include <__package_shared.h>
 
 #include <qwebelement.h>
 #include <QVariant>
-#include <qpainter.h>
-#include <qrect.h>
-#include <qstringlist.h>
+#include <QPainter>
+#include <QtWebKitWidgets/QWebFrame>
 #include <qwebelement.h>
 #include <qwebframe.h>
 
@@ -115,7 +115,7 @@ static const char * const qtscript_QWebElement_function_signatures[] = {
     , "String namespaceUri, String name"
     , "String name"
     , ""
-    , "QPainter painter"
+    , "QPainter painter\nQPainter painter, QRect clipRect"
     , "String markup\nQWebElement element"
     , "String name, String value"
     , "String namespaceUri, String name, String value"
@@ -176,7 +176,7 @@ static const int qtscript_QWebElement_function_lengths[] = {
     , 2
     , 1
     , 0
-    , 1
+    , 2
     , 1
     , 2
     , 3
@@ -207,6 +207,7 @@ static QScriptValue qtscript_QWebElement_throw_ambiguity_error_helper(
         .arg(functionName).arg(fullSignatures.join(QLatin1String("\n"))));
 }
 
+//Q_DECLARE_METATYPE(QWebElement)
 Q_DECLARE_METATYPE(QWebElement*)
 Q_DECLARE_METATYPE(QWebElement::StyleResolveStrategy)
 Q_DECLARE_METATYPE(QPainter*)
@@ -555,7 +556,7 @@ static QScriptValue qtscript_QWebElement_prototype_call(QScriptContext *context,
     case 25:
     if (context->argumentCount() == 1) {
         QWebElement _q_arg0 = qscriptvalue_cast<QWebElement>(context->argument(0));
-        QWebElement _q_result = _q_self->operator=(_q_arg0);
+        QWebElement& _q_result = _q_self->operator=(_q_arg0);
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
@@ -662,6 +663,12 @@ static QScriptValue qtscript_QWebElement_prototype_call(QScriptContext *context,
         _q_self->render(_q_arg0);
         return context->engine()->undefinedValue();
     }
+    if (context->argumentCount() == 2) {
+        QPainter* _q_arg0 = qscriptvalue_cast<QPainter*>(context->argument(0));
+        QRect _q_arg1 = qscriptvalue_cast<QRect>(context->argument(1));
+        _q_self->render(_q_arg0, _q_arg1);
+        return context->engine()->undefinedValue();
+    }
     break;
 
     case 38:
@@ -755,7 +762,7 @@ static QScriptValue qtscript_QWebElement_prototype_call(QScriptContext *context,
 
     case 48:
     if (context->argumentCount() == 0) {
-        QWebElement _q_result = _q_self->takeFromDocument();
+        QWebElement& _q_result = _q_self->takeFromDocument();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
