@@ -4,6 +4,7 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
+#include <__package_shared.h>
 
 #include <qpaintengine.h>
 #include <QVarLengthArray>
@@ -142,21 +143,21 @@ static QScriptValue qtscript_QPaintEngine_throw_ambiguity_error_helper(
 
 Q_DECLARE_METATYPE(QPaintEngine*)
 Q_DECLARE_METATYPE(QtScriptShell_QPaintEngine*)
-Q_DECLARE_METATYPE(QPaintEngine::PolygonDrawMode)
 Q_DECLARE_METATYPE(QPaintEngine::Type)
+Q_DECLARE_METATYPE(QPaintEngine::PolygonDrawMode)
 Q_DECLARE_METATYPE(QPaintEngine::PaintEngineFeature)
 Q_DECLARE_METATYPE(QFlags<QPaintEngine::PaintEngineFeature>)
 Q_DECLARE_METATYPE(QPaintEngine::DirtyFlag)
 Q_DECLARE_METATYPE(QFlags<QPaintEngine::DirtyFlag>)
 Q_DECLARE_METATYPE(QPaintDevice*)
 Q_DECLARE_METATYPE(QFlags<Qt::ImageConversionFlag>)
-Q_DECLARE_METATYPE(QLine*)
-Q_DECLARE_METATYPE(QLineF*)
+Q_DECLARE_METATYPE(const QLine*)
+Q_DECLARE_METATYPE(const QLineF*)
 Q_DECLARE_METATYPE(QPainterPath)
-Q_DECLARE_METATYPE(QPoint*)
-Q_DECLARE_METATYPE(QPointF*)
-Q_DECLARE_METATYPE(QRect*)
-Q_DECLARE_METATYPE(QRectF*)
+Q_DECLARE_METATYPE(const QPoint*)
+Q_DECLARE_METATYPE(const QPointF*)
+Q_DECLARE_METATYPE(const QRect*)
+Q_DECLARE_METATYPE(const QRectF*)
 Q_DECLARE_METATYPE(QTextItem)
 Q_DECLARE_METATYPE(QPainter*)
 Q_DECLARE_METATYPE(QPaintEngineState)
@@ -192,6 +193,113 @@ static QScriptValue qtscript_create_flags_class_helper(
     return engine->newFunction(construct, proto);
 }
 
+//
+// QPaintEngine::Type
+//
+
+static const QPaintEngine::Type qtscript_QPaintEngine_Type_values[] = {
+    QPaintEngine::X11
+    , QPaintEngine::Windows
+    , QPaintEngine::QuickDraw
+    , QPaintEngine::CoreGraphics
+    , QPaintEngine::MacPrinter
+    , QPaintEngine::QWindowSystem
+    , QPaintEngine::PostScript
+    , QPaintEngine::OpenGL
+    , QPaintEngine::Picture
+    , QPaintEngine::SVG
+    , QPaintEngine::Raster
+    , QPaintEngine::Direct3D
+    , QPaintEngine::Pdf
+    , QPaintEngine::OpenVG
+    , QPaintEngine::OpenGL2
+    , QPaintEngine::PaintBuffer
+    , QPaintEngine::Blitter
+    , QPaintEngine::Direct2D
+    , QPaintEngine::User
+    , QPaintEngine::MaxUser
+};
+
+static const char * const qtscript_QPaintEngine_Type_keys[] = {
+    "X11"
+    , "Windows"
+    , "QuickDraw"
+    , "CoreGraphics"
+    , "MacPrinter"
+    , "QWindowSystem"
+    , "PostScript"
+    , "OpenGL"
+    , "Picture"
+    , "SVG"
+    , "Raster"
+    , "Direct3D"
+    , "Pdf"
+    , "OpenVG"
+    , "OpenGL2"
+    , "PaintBuffer"
+    , "Blitter"
+    , "Direct2D"
+    , "User"
+    , "MaxUser"
+};
+
+static QString qtscript_QPaintEngine_Type_toStringHelper(QPaintEngine::Type value)
+{
+    for (int i = 0; i < 20; ++i) {
+        if (qtscript_QPaintEngine_Type_values[i] == value)
+            return QString::fromLatin1(qtscript_QPaintEngine_Type_keys[i]);
+    }
+    return QString();
+}
+
+static QScriptValue qtscript_QPaintEngine_Type_toScriptValue(QScriptEngine *engine, const QPaintEngine::Type &value)
+{
+    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QPaintEngine"));
+    return clazz.property(qtscript_QPaintEngine_Type_toStringHelper(value));
+}
+
+static void qtscript_QPaintEngine_Type_fromScriptValue(const QScriptValue &value, QPaintEngine::Type &out)
+{
+    out = qvariant_cast<QPaintEngine::Type>(value.toVariant());
+}
+
+static QScriptValue qtscript_construct_QPaintEngine_Type(QScriptContext *context, QScriptEngine *engine)
+{
+    int arg = context->argument(0).toInt32();
+    for (int i = 0; i < 20; ++i) {
+        if (qtscript_QPaintEngine_Type_values[i] == arg)
+            return qScriptValueFromValue(engine,  static_cast<QPaintEngine::Type>(arg));
+    }
+    return context->throwError(QString::fromLatin1("Type(): invalid enum value (%0)").arg(arg));
+}
+
+static QScriptValue qtscript_QPaintEngine_Type_valueOf(QScriptContext *context, QScriptEngine *engine)
+{
+    QPaintEngine::Type value = qscriptvalue_cast<QPaintEngine::Type>(context->thisObject());
+    return QScriptValue(engine, static_cast<int>(value));
+}
+
+static QScriptValue qtscript_QPaintEngine_Type_toString(QScriptContext *context, QScriptEngine *engine)
+{
+    QPaintEngine::Type value = qscriptvalue_cast<QPaintEngine::Type>(context->thisObject());
+    return QScriptValue(engine, qtscript_QPaintEngine_Type_toStringHelper(value));
+}
+
+static QScriptValue qtscript_create_QPaintEngine_Type_class(QScriptEngine *engine, QScriptValue &clazz)
+{
+    QScriptValue ctor = qtscript_create_enum_class_helper(
+        engine, qtscript_construct_QPaintEngine_Type,
+        qtscript_QPaintEngine_Type_valueOf, qtscript_QPaintEngine_Type_toString);
+    qScriptRegisterMetaType<QPaintEngine::Type>(engine, qtscript_QPaintEngine_Type_toScriptValue,
+        qtscript_QPaintEngine_Type_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
+    for (int i = 0; i < 20; ++i) {
+        clazz.setProperty(QString::fromLatin1(qtscript_QPaintEngine_Type_keys[i]),
+            engine->newVariant(qVariantFromValue(qtscript_QPaintEngine_Type_values[i])),
+            QScriptValue::ReadOnly | QScriptValue::Undeletable);
+    }
+    return ctor;
+}
+
 //
 // QPaintEngine::PolygonDrawMode
 //
@@ -263,109 +371,6 @@ static QScriptValue qtscript_create_QPaintEngine_PolygonDrawMode_class(QScriptEn
     return ctor;
 }
 
-//
-// QPaintEngine::Type
-//
-
-static const QPaintEngine::Type qtscript_QPaintEngine_Type_values[] = {
-    QPaintEngine::X11
-    , QPaintEngine::Windows
-    , QPaintEngine::QuickDraw
-    , QPaintEngine::CoreGraphics
-    , QPaintEngine::MacPrinter
-    , QPaintEngine::QWindowSystem
-    , QPaintEngine::PostScript
-    , QPaintEngine::OpenGL
-    , QPaintEngine::Picture
-    , QPaintEngine::SVG
-    , QPaintEngine::Raster
-    , QPaintEngine::Direct3D
-    , QPaintEngine::Pdf
-    , QPaintEngine::OpenVG
-    , QPaintEngine::OpenGL2
-    , QPaintEngine::PaintBuffer
-    , QPaintEngine::User
-    , QPaintEngine::MaxUser
-};
-
-static const char * const qtscript_QPaintEngine_Type_keys[] = {
-    "X11"
-    , "Windows"
-    , "QuickDraw"
-    , "CoreGraphics"
-    , "MacPrinter"
-    , "QWindowSystem"
-    , "PostScript"
-    , "OpenGL"
-    , "Picture"
-    , "SVG"
-    , "Raster"
-    , "Direct3D"
-    , "Pdf"
-    , "OpenVG"
-    , "OpenGL2"
-    , "PaintBuffer"
-    , "User"
-    , "MaxUser"
-};
-
-static QString qtscript_QPaintEngine_Type_toStringHelper(QPaintEngine::Type value)
-{
-    for (int i = 0; i < 18; ++i) {
-        if (qtscript_QPaintEngine_Type_values[i] == value)
-            return QString::fromLatin1(qtscript_QPaintEngine_Type_keys[i]);
-    }
-    return QString();
-}
-
-static QScriptValue qtscript_QPaintEngine_Type_toScriptValue(QScriptEngine *engine, const QPaintEngine::Type &value)
-{
-    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QPaintEngine"));
-    return clazz.property(qtscript_QPaintEngine_Type_toStringHelper(value));
-}
-
-static void qtscript_QPaintEngine_Type_fromScriptValue(const QScriptValue &value, QPaintEngine::Type &out)
-{
-    out = qvariant_cast<QPaintEngine::Type>(value.toVariant());
-}
-
-static QScriptValue qtscript_construct_QPaintEngine_Type(QScriptContext *context, QScriptEngine *engine)
-{
-    int arg = context->argument(0).toInt32();
-    for (int i = 0; i < 18; ++i) {
-        if (qtscript_QPaintEngine_Type_values[i] == arg)
-            return qScriptValueFromValue(engine,  static_cast<QPaintEngine::Type>(arg));
-    }
-    return context->throwError(QString::fromLatin1("Type(): invalid enum value (%0)").arg(arg));
-}
-
-static QScriptValue qtscript_QPaintEngine_Type_valueOf(QScriptContext *context, QScriptEngine *engine)
-{
-    QPaintEngine::Type value = qscriptvalue_cast<QPaintEngine::Type>(context->thisObject());
-    return QScriptValue(engine, static_cast<int>(value));
-}
-
-static QScriptValue qtscript_QPaintEngine_Type_toString(QScriptContext *context, QScriptEngine *engine)
-{
-    QPaintEngine::Type value = qscriptvalue_cast<QPaintEngine::Type>(context->thisObject());
-    return QScriptValue(engine, qtscript_QPaintEngine_Type_toStringHelper(value));
-}
-
-static QScriptValue qtscript_create_QPaintEngine_Type_class(QScriptEngine *engine, QScriptValue &clazz)
-{
-    QScriptValue ctor = qtscript_create_enum_class_helper(
-        engine, qtscript_construct_QPaintEngine_Type,
-        qtscript_QPaintEngine_Type_valueOf, qtscript_QPaintEngine_Type_toString);
-    qScriptRegisterMetaType<QPaintEngine::Type>(engine, qtscript_QPaintEngine_Type_toScriptValue,
-        qtscript_QPaintEngine_Type_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 18; ++i) {
-        clazz.setProperty(QString::fromLatin1(qtscript_QPaintEngine_Type_keys[i]),
-            engine->newVariant(qVariantFromValue(qtscript_QPaintEngine_Type_values[i])),
-            QScriptValue::ReadOnly | QScriptValue::Undeletable);
-    }
-    return ctor;
-}
-
 //
 // QPaintEngine::PaintEngineFeature
 //
@@ -803,15 +808,15 @@ static QScriptValue qtscript_QPaintEngine_prototype_call(QScriptContext *context
 
     case 5:
     if (context->argumentCount() == 2) {
-        if (qscriptvalue_cast<QLine*>(context->argument(0))
+        if (qscriptvalue_cast<const QLine*>(context->argument(0))
             && context->argument(1).isNumber()) {
-            QLine* _q_arg0 = qscriptvalue_cast<QLine*>(context->argument(0));
+            const QLine* _q_arg0 = qscriptvalue_cast<const QLine*>(context->argument(0));
             int _q_arg1 = context->argument(1).toInt32();
             _q_self->drawLines(_q_arg0, _q_arg1);
             return context->engine()->undefinedValue();
-        } else if (qscriptvalue_cast<QLineF*>(context->argument(0))
+        } else if (qscriptvalue_cast<const QLineF*>(context->argument(0))
             && context->argument(1).isNumber()) {
-            QLineF* _q_arg0 = qscriptvalue_cast<QLineF*>(context->argument(0));
+            const QLineF* _q_arg0 = qscriptvalue_cast<const QLineF*>(context->argument(0));
             int _q_arg1 = context->argument(1).toInt32();
             _q_self->drawLines(_q_arg0, _q_arg1);
             return context->engine()->undefinedValue();
@@ -839,15 +844,15 @@ static QScriptValue qtscript_QPaintEngine_prototype_call(QScriptContext *context
 
     case 8:
     if (context->argumentCount() == 2) {
-        if (qscriptvalue_cast<QPoint*>(context->argument(0))
+        if (qscriptvalue_cast<const QPoint*>(context->argument(0))
             && context->argument(1).isNumber()) {
-            QPoint* _q_arg0 = qscriptvalue_cast<QPoint*>(context->argument(0));
+            const QPoint* _q_arg0 = qscriptvalue_cast<const QPoint*>(context->argument(0));
             int _q_arg1 = context->argument(1).toInt32();
             _q_self->drawPoints(_q_arg0, _q_arg1);
             return context->engine()->undefinedValue();
-        } else if (qscriptvalue_cast<QPointF*>(context->argument(0))
+        } else if (qscriptvalue_cast<const QPointF*>(context->argument(0))
             && context->argument(1).isNumber()) {
-            QPointF* _q_arg0 = qscriptvalue_cast<QPointF*>(context->argument(0));
+            const QPointF* _q_arg0 = qscriptvalue_cast<const QPointF*>(context->argument(0));
             int _q_arg1 = context->argument(1).toInt32();
             _q_self->drawPoints(_q_arg0, _q_arg1);
             return context->engine()->undefinedValue();
@@ -857,18 +862,18 @@ static QScriptValue qtscript_QPaintEngine_prototype_call(QScriptContext *context
 
     case 9:
     if (context->argumentCount() == 3) {
-        if (qscriptvalue_cast<QPoint*>(context->argument(0))
+        if (qscriptvalue_cast<const QPoint*>(context->argument(0))
             && context->argument(1).isNumber()
             && (qMetaTypeId<QPaintEngine::PolygonDrawMode>() == context->argument(2).toVariant().userType())) {
-            QPoint* _q_arg0 = qscriptvalue_cast<QPoint*>(context->argument(0));
+            const QPoint* _q_arg0 = qscriptvalue_cast<const QPoint*>(context->argument(0));
             int _q_arg1 = context->argument(1).toInt32();
             QPaintEngine::PolygonDrawMode _q_arg2 = qscriptvalue_cast<QPaintEngine::PolygonDrawMode>(context->argument(2));
             _q_self->drawPolygon(_q_arg0, _q_arg1, _q_arg2);
             return context->engine()->undefinedValue();
-        } else if (qscriptvalue_cast<QPointF*>(context->argument(0))
+        } else if (qscriptvalue_cast<const QPointF*>(context->argument(0))
             && context->argument(1).isNumber()
             && (qMetaTypeId<QPaintEngine::PolygonDrawMode>() == context->argument(2).toVariant().userType())) {
-            QPointF* _q_arg0 = qscriptvalue_cast<QPointF*>(context->argument(0));
+            const QPointF* _q_arg0 = qscriptvalue_cast<const QPointF*>(context->argument(0));
             int _q_arg1 = context->argument(1).toInt32();
             QPaintEngine::PolygonDrawMode _q_arg2 = qscriptvalue_cast<QPaintEngine::PolygonDrawMode>(context->argument(2));
             _q_self->drawPolygon(_q_arg0, _q_arg1, _q_arg2);
@@ -879,15 +884,15 @@ static QScriptValue qtscript_QPaintEngine_prototype_call(QScriptContext *context
 
     case 10:
     if (context->argumentCount() == 2) {
-        if (qscriptvalue_cast<QRect*>(context->argument(0))
+        if (qscriptvalue_cast<const QRect*>(context->argument(0))
             && context->argument(1).isNumber()) {
-            QRect* _q_arg0 = qscriptvalue_cast<QRect*>(context->argument(0));
+            const QRect* _q_arg0 = qscriptvalue_cast<const QRect*>(context->argument(0));
             int _q_arg1 = context->argument(1).toInt32();
             _q_self->drawRects(_q_arg0, _q_arg1);
             return context->engine()->undefinedValue();
-        } else if (qscriptvalue_cast<QRectF*>(context->argument(0))
+        } else if (qscriptvalue_cast<const QRectF*>(context->argument(0))
             && context->argument(1).isNumber()) {
-            QRectF* _q_arg0 = qscriptvalue_cast<QRectF*>(context->argument(0));
+            const QRectF* _q_arg0 = qscriptvalue_cast<const QRectF*>(context->argument(0));
             int _q_arg1 = context->argument(1).toInt32();
             _q_self->drawRects(_q_arg0, _q_arg1);
             return context->engine()->undefinedValue();
@@ -1094,10 +1099,10 @@ QScriptValue qtscript_create_QPaintEngine_class(QScriptEngine *engine)
     QScriptValue ctor = engine->newFunction(qtscript_QPaintEngine_static_call, proto, qtscript_QPaintEngine_function_lengths[0]);
     ctor.setData(QScriptValue(engine, uint(0xBABE0000 + 0)));
 
-    ctor.setProperty(QString::fromLatin1("PolygonDrawMode"),
-        qtscript_create_QPaintEngine_PolygonDrawMode_class(engine, ctor));
     ctor.setProperty(QString::fromLatin1("Type"),
         qtscript_create_QPaintEngine_Type_class(engine, ctor));
+    ctor.setProperty(QString::fromLatin1("PolygonDrawMode"),
+        qtscript_create_QPaintEngine_PolygonDrawMode_class(engine, ctor));
     ctor.setProperty(QString::fromLatin1("PaintEngineFeature"),
         qtscript_create_QPaintEngine_PaintEngineFeature_class(engine, ctor));
     ctor.setProperty(QString::fromLatin1("PaintEngineFeatures"),
