@@ -4,6 +4,7 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
+#include <__package_shared.h>
 
 #include <qlocalsocket.h>
 #include <QVariant>
@@ -29,8 +30,7 @@ static const char * const qtscript_QLocalSocket_function_names[] = {
     , "readBufferSize"
     , "serverName"
     , "setReadBufferSize"
-    , "setSocketDescriptor"
-    , "socketDescriptor"
+    , "setServerName"
     , "state"
     , "waitForConnected"
     , "waitForDisconnected"
@@ -42,7 +42,7 @@ static const char * const qtscript_QLocalSocket_function_signatures[] = {
     // static
     // prototype
     , ""
-    , "String name, OpenMode openMode"
+    , "OpenMode openMode\nString name, OpenMode openMode"
     , ""
     , ""
     , ""
@@ -51,8 +51,7 @@ static const char * const qtscript_QLocalSocket_function_signatures[] = {
     , ""
     , ""
     , "qint64 size"
-    , "quintptr socketDescriptor, LocalSocketState socketState, OpenMode openMode"
-    , ""
+    , "String name"
     , ""
     , "int msecs"
     , "int msecs"
@@ -73,8 +72,7 @@ static const int qtscript_QLocalSocket_function_lengths[] = {
     , 0
     , 0
     , 1
-    , 3
-    , 0
+    , 1
     , 0
     , 1
     , 1
@@ -97,7 +95,6 @@ Q_DECLARE_METATYPE(QtScriptShell_QLocalSocket*)
 Q_DECLARE_METATYPE(QLocalSocket::LocalSocketState)
 Q_DECLARE_METATYPE(QLocalSocket::LocalSocketError)
 Q_DECLARE_METATYPE(QFlags<QIODevice::OpenModeFlag>)
-Q_DECLARE_METATYPE(quintptr)
 Q_DECLARE_METATYPE(QIODevice*)
 
 static QScriptValue qtscript_create_enum_class_helper(
@@ -204,6 +201,7 @@ static const QLocalSocket::LocalSocketError qtscript_QLocalSocket_LocalSocketErr
     , QLocalSocket::DatagramTooLargeError
     , QLocalSocket::ConnectionError
     , QLocalSocket::UnsupportedSocketOperationError
+    , QLocalSocket::OperationError
 };
 
 static const char * const qtscript_QLocalSocket_LocalSocketError_keys[] = {
@@ -217,11 +215,12 @@ static const char * const qtscript_QLocalSocket_LocalSocketError_keys[] = {
     , "DatagramTooLargeError"
     , "ConnectionError"
     , "UnsupportedSocketOperationError"
+    , "OperationError"
 };
 
 static QString qtscript_QLocalSocket_LocalSocketError_toStringHelper(QLocalSocket::LocalSocketError value)
 {
-    for (int i = 0; i < 10; ++i) {
+    for (int i = 0; i < 11; ++i) {
         if (qtscript_QLocalSocket_LocalSocketError_values[i] == value)
             return QString::fromLatin1(qtscript_QLocalSocket_LocalSocketError_keys[i]);
     }
@@ -242,7 +241,7 @@ static void qtscript_QLocalSocket_LocalSocketError_fromScriptValue(const QScript
 static QScriptValue qtscript_construct_QLocalSocket_LocalSocketError(QScriptContext *context, QScriptEngine *engine)
 {
     int arg = context->argument(0).toInt32();
-    for (int i = 0; i < 10; ++i) {
+    for (int i = 0; i < 11; ++i) {
         if (qtscript_QLocalSocket_LocalSocketError_values[i] == arg)
             return qScriptValueFromValue(engine,  static_cast<QLocalSocket::LocalSocketError>(arg));
     }
@@ -268,7 +267,7 @@ static QScriptValue qtscript_create_QLocalSocket_LocalSocketError_class(QScriptE
         qtscript_QLocalSocket_LocalSocketError_valueOf, qtscript_QLocalSocket_LocalSocketError_toString);
     qScriptRegisterMetaType<QLocalSocket::LocalSocketError>(engine, qtscript_QLocalSocket_LocalSocketError_toScriptValue,
         qtscript_QLocalSocket_LocalSocketError_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 10; ++i) {
+    for (int i = 0; i < 11; ++i) {
         clazz.setProperty(QString::fromLatin1(qtscript_QLocalSocket_LocalSocketError_keys[i]),
             engine->newVariant(qVariantFromValue(qtscript_QLocalSocket_LocalSocketError_values[i])),
             QScriptValue::ReadOnly | QScriptValue::Undeletable);
@@ -290,7 +289,7 @@ static QScriptValue qtscript_QLocalSocket_prototype_call(QScriptContext *context
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 15;
+        _id = 0xBABE0000 + 14;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -310,11 +309,21 @@ static QScriptValue qtscript_QLocalSocket_prototype_call(QScriptContext *context
     break;
 
     case 1:
-    if (context->argumentCount() == 1) {
-        QString _q_arg0 = context->argument(0).toString();
-        _q_self->connectToServer(_q_arg0);
+    if (context->argumentCount() == 0) {
+        _q_self->connectToServer();
         return context->engine()->undefinedValue();
     }
+    if (context->argumentCount() == 1) {
+        if ((qMetaTypeId<QFlags<QIODevice::OpenModeFlag> >() == context->argument(0).toVariant().userType())) {
+            QFlags<QIODevice::OpenModeFlag> _q_arg0 = qscriptvalue_cast<QFlags<QIODevice::OpenModeFlag> >(context->argument(0));
+            _q_self->connectToServer(_q_arg0);
+            return context->engine()->undefinedValue();
+        } else if (context->argument(0).isString()) {
+            QString _q_arg0 = context->argument(0).toString();
+            _q_self->connectToServer(_q_arg0);
+            return context->engine()->undefinedValue();
+        }
+    }
     if (context->argumentCount() == 2) {
         QString _q_arg0 = context->argument(0).toString();
         QFlags<QIODevice::OpenModeFlag> _q_arg1 = qscriptvalue_cast<QFlags<QIODevice::OpenModeFlag> >(context->argument(1));
@@ -382,40 +391,20 @@ static QScriptValue qtscript_QLocalSocket_prototype_call(QScriptContext *context
 
     case 10:
     if (context->argumentCount() == 1) {
-        quintptr _q_arg0 = qscriptvalue_cast<quintptr>(context->argument(0));
-        bool _q_result = _q_self->setSocketDescriptor(_q_arg0);
-        return QScriptValue(context->engine(), _q_result);
-    }
-    if (context->argumentCount() == 2) {
-        quintptr _q_arg0 = qscriptvalue_cast<quintptr>(context->argument(0));
-        QLocalSocket::LocalSocketState _q_arg1 = qscriptvalue_cast<QLocalSocket::LocalSocketState>(context->argument(1));
-        bool _q_result = _q_self->setSocketDescriptor(_q_arg0, _q_arg1);
-        return QScriptValue(context->engine(), _q_result);
-    }
-    if (context->argumentCount() == 3) {
-        quintptr _q_arg0 = qscriptvalue_cast<quintptr>(context->argument(0));
-        QLocalSocket::LocalSocketState _q_arg1 = qscriptvalue_cast<QLocalSocket::LocalSocketState>(context->argument(1));
-        QFlags<QIODevice::OpenModeFlag> _q_arg2 = qscriptvalue_cast<QFlags<QIODevice::OpenModeFlag> >(context->argument(2));
-        bool _q_result = _q_self->setSocketDescriptor(_q_arg0, _q_arg1, _q_arg2);
-        return QScriptValue(context->engine(), _q_result);
+        QString _q_arg0 = context->argument(0).toString();
+        _q_self->setServerName(_q_arg0);
+        return context->engine()->undefinedValue();
     }
     break;
 
     case 11:
-    if (context->argumentCount() == 0) {
-        quintptr _q_result = _q_self->socketDescriptor();
-        return qScriptValueFromValue(context->engine(), _q_result);
-    }
-    break;
-
-    case 12:
     if (context->argumentCount() == 0) {
         QLocalSocket::LocalSocketState _q_result = _q_self->state();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 13:
+    case 12:
     if (context->argumentCount() == 0) {
         bool _q_result = _q_self->waitForConnected();
         return QScriptValue(context->engine(), _q_result);
@@ -427,7 +416,7 @@ static QScriptValue qtscript_QLocalSocket_prototype_call(QScriptContext *context
     }
     break;
 
-    case 14:
+    case 13:
     if (context->argumentCount() == 0) {
         bool _q_result = _q_self->waitForDisconnected();
         return QScriptValue(context->engine(), _q_result);
@@ -439,7 +428,7 @@ static QScriptValue qtscript_QLocalSocket_prototype_call(QScriptContext *context
     }
     break;
 
-    case 15: {
+    case 14: {
     QString result = QString::fromLatin1("QLocalSocket");
     return QScriptValue(context->engine(), result);
     }
@@ -499,7 +488,7 @@ QScriptValue qtscript_create_QLocalSocket_class(QScriptEngine *engine)
     engine->setDefaultPrototype(qMetaTypeId<QLocalSocket*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QLocalSocket*)0));
     proto.setPrototype(engine->defaultPrototype(qMetaTypeId<QIODevice*>()));
-    for (int i = 0; i < 16; ++i) {
+    for (int i = 0; i < 15; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QLocalSocket_prototype_call, qtscript_QLocalSocket_function_lengths[i+1]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QLocalSocket_function_names[i+1]),
