@@ -183,11 +183,11 @@ static QScriptValue qtscript_QItemSelection_throw_ambiguity_error_helper(
         .arg(functionName).arg(fullSignatures.join(QLatin1String("\n"))));
 }
 
-Q_DECLARE_METATYPE(QItemSelection)
+//Q_DECLARE_METATYPE(QItemSelection)
 Q_DECLARE_METATYPE(QItemSelection*)
-Q_DECLARE_METATYPE(QItemSelectionRange)
+//Q_DECLARE_METATYPE(QItemSelectionRange)
 Q_DECLARE_METATYPE(QList<QItemSelectionRange >)
-Q_DECLARE_METATYPE(QList<QModelIndex >)
+//Q_DECLARE_METATYPE(QList<QModelIndex >)
 Q_DECLARE_METATYPE(QFlags<QItemSelectionModel::SelectionFlag>)
 Q_DECLARE_METATYPE(QVector<QItemSelectionRange >)
 
