@@ -20,14 +20,23 @@
 
 #include "RAttributeDefinitionEntity.h"
 #include "RAttributeEntity.h"
+#include "RBlock.h"
 #include "RBlockReferenceEntity.h"
 #include "RClipboardOperation.h"
+#include "RDocument.h"
+#include "RLayer.h"
+#include "RS.h"
 #include "RSettings.h"
 #include "RStorage.h"
 #include "RUnit.h"
 
 
-RClipboardOperation::RClipboardOperation() : copyEmptyBlocks(false), copyAllLayers(false), keepSelection(false) {
+RClipboardOperation::RClipboardOperation() :
+    copyEmptyBlocks(false),
+    copyAllLayers(false),
+    keepSelection(false),
+    blockOwnership(false),
+    customEntityType(RS::EntityUnknown) {
 }
 
 void RClipboardOperation::copy(RDocument& src, RDocument& dest,
@@ -96,6 +105,9 @@ void RClipboardOperation::copy(RDocument& src, RDocument& dest,
             block = QSharedPointer<RBlock> (new RBlock(&dest, blockName,
                     RVector(0, 0, 0)));
             block->setCustomProperties(blockProperties);
+            if (blockOwnership) {
+                block->setOwnedByReference(true);
+            }
             transaction.overwriteBlock(block);
         }
 
@@ -108,9 +120,10 @@ void RClipboardOperation::copy(RDocument& src, RDocument& dest,
 
         // create new block reference that references new, overwritten or existing block
         // (insert later, when block is complete, so we have bounding box for spatial index):
-        RBlockReferenceEntity* ref = new RBlockReferenceEntity(&dest,
-                RBlockReferenceData(block->getId(), RVector(0,0,0),
-                                    RVector(1.0, 1.0, 1.0), 0.0));
+        //RBlockReferenceEntity* ref = new RBlockReferenceEntity(&dest,
+        RBlockReferenceData data(block->getId(), RVector(0,0,0),
+                                    RVector(1.0, 1.0, 1.0), 0.0);
+        RBlockReferenceEntity* ref = createBlockReferenceEntity(dest, customEntityType, data);
         refp = QSharedPointer<RBlockReferenceEntity>(ref);
         refp->setBlockId(dest.getCurrentBlockId());
         off = RVector(0, 0, 0);
@@ -149,6 +162,7 @@ void RClipboardOperation::copy(RDocument& src, RDocument& dest,
                 )
             );
             att->scale(unitScale);
+            att->setInvisible(attDef->isInvisible());
             refp->applyTransformationTo(*att);
 
             // assign values to attributes:
@@ -472,7 +486,7 @@ void RClipboardOperation::copyEntity(
     }
 
     // add entity self:
-    QSharedPointer<REntity> destEntity = QSharedPointer<REntity>(entity.clone());
+    QSharedPointer<REntity> destEntity = entity.cloneToEntity();
     //dest.getStorage().setObjectId(*destEntity.data(), RObject::INVALID_ID);
     dest.getStorage().setObjectHandle(*destEntity.data(), RObject::INVALID_HANDLE);
 
@@ -610,7 +624,7 @@ QSharedPointer<RBlock> RClipboardOperation::copyBlock(
             }
         }
         if (!dest.hasBlock(destBlockName) || (overwriteBlocks && blockName.isNull())) {
-            destBlock = QSharedPointer<RBlock> (srcBlock->clone());
+            destBlock = srcBlock->cloneToBlock();
             dest.getStorage().setObjectId(*destBlock.data(), RObject::INVALID_ID);
             dest.getStorage().setObjectHandle(*destBlock.data(), RObject::INVALID_HANDLE);
             destBlock->setDocument(&dest);
@@ -686,7 +700,7 @@ QSharedPointer<RLayer> RClipboardOperation::copyLayer(
     }
     else {
         if (!dest.hasLayer(srcLayerName) || overwriteLayers) {
-            destLayer = QSharedPointer<RLayer>(srcLayer->clone());
+            destLayer = srcLayer->cloneToLayer();
             destLayer->setDocument(&dest);
             if (destLayer->getDocument()!=srcLayer->getDocument()) {
                 dest.getStorage().setObjectId(*destLayer.data(), RObject::INVALID_ID);
@@ -740,7 +754,7 @@ QSharedPointer<RLinetype> RClipboardOperation::copyLinetype(
     }
     else {
         if (!dest.hasLinetype(srcLinetypeName) || overwriteLinetypes) {
-            destLinetype = QSharedPointer<RLinetype>(srcLinetype->clone());
+            destLinetype = srcLinetype->cloneToLinetype();
             destLinetype->setDocument(&dest);
             if (destLinetype->getDocument()!=srcLinetype->getDocument()) {
                 dest.getStorage().setObjectId(*destLinetype.data(), RObject::INVALID_ID);
@@ -758,3 +772,7 @@ QSharedPointer<RLinetype> RClipboardOperation::copyLinetype(
 
     return destLinetype;
 }
+
+RBlockReferenceEntity* RClipboardOperation::createBlockReferenceEntity(RDocument& doc, RS::EntityType customEntityType, const RBlockReferenceData& data) {
+    return new RBlockReferenceEntity(&doc, data);
+}
